#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Thin Client     |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April, May 2000                                     |
#|                                                            |
#| Filename: distro_specific.tcl                              |
#| Last Modified: September 19, 2000 by Ryan Harper           |
#| Changes: Added check for rebuilding packages RAH 09.19.00  |
#| Description: File where user may add packages and the      |
#| skeleton code required for the interface                   |
#| Also, this file includes all the distrobution specific     |
#| information and procedure calls                            |
#`------------------------------------------------------------'

#--- ----------------
#--- Calls up the Documentation for each item.  Uses the show_help_file proc which spawns
#--- a new window and reads the first argument from /IBM/CFBuilder_X.X/InstallDocs/
#--- ----------------
proc pPackInfo {} {
  global PACKAGE_UNDOCUMENTED
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting pPackInfo"]
  flush $lh

  set item [.win.lbAvail curselection]
  if {[llength $item] < 1} { 
    tk_messageBox -message "Please select an Item first"
    return
  } else {
    switch [.win.lbAvail get [lindex $item 0]] {
      BaseOS { show_help_file "BaseOS.doc" "BaseOS Package Description" }
      Netscape_4.61 { show_help_file "Netscape_4.61.doc" "Netscape 4.61 Package Description" }
      ICAClient { show_help_file "ICAClient.doc" "ICA Client Package Description" }
      Ftp { show_help_file "Ftp.doc" "Ftp Package Description" }
      Telnet { show_help_file "Telnet.doc" "Telnet Package Description" }
	FVWM2 { show_help_file "FVWM2.doc" "FVWM2 Package Description" }
      Default { tk_messageBox -message $PACKAGE_UNDOCUMENTED }
    }
  }
}

#--- ------------
#--- BuildList reads the items in the right side listbox, packages to be built, 
#--- and calls the build procedure.  All procedures use the get_dir to set up
#--- env vars for the shell scripts that install the packages and tar up the files
#--- and their respective libraries with the exception of BaseOS install.  It is
#--- a separate procedure that runs several scripts to make the directory structure
#--- and then populates it with the files listed in BaseTarFileList.txt.
#--- ------------

proc pBuildList {} {
  global PACKAGE_BUILD_MAIN
  global PACKAGE_BUILD_DONE
  global PACKAGE_UNDOCUMENTED
  global CFBUILD_DIR_NO_SLASH
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting pBuildList"]
  flush $lh

  set itemlist [.win.lbBuild get 0 [.win.lbBuild size]]
  if {[llength $itemlist] <= 0} {
    tk_messageBox -message $PACKAGE_BUILD_MAIN
  } else {
    foreach x $itemlist {
      switch $x {
        BaseOS { 
		set fi "$CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz"
                if { [file exists $fi] } {
                        if {[confirm_ask "This package is already built.\nDo you want to build again?"]} {
                                set waitvar 0
                                BaseOSInstall
                        }
                } else {
                        BaseOSInstall
                }   
        }
        Netscape_4.61 {
		set fi "$CFBUILD_DIR_NO_SLASH/Packages/netscape.tar.gz"
                if { [file exists $fi] } {
                        if {[confirm_ask "This package is already built.\nDo you want to build again?"]} {
                                set waitvar 0
				get_dir "Where are the Netscape RPMS\n (main & common) ?"\
					"netscape_rpm"\
					"2"\
					"set_env netscape_rpm_install"
				set waitvar 1
				vwait waitvar
			}
		} else {
				get_dir "Where are the Netscape RPMS\n (main & common) ?"\
					"netscape_rpm"\
					"2"\
					"set_env netscape_rpm_install"
				set waitvar 1
				vwait waitvar
		}
        }
        ICAClient { 
		set fi "$CFBUILD_DIR_NO_SLASH/Packages/ica.tar.gz"
                if { [file exists $fi] } {
                        if {[confirm_ask "This package is already built.\nDo you want to build again?"]} {
                                set waitvar 0
				get_dir "Where is the ICAClient RPM?"\
					"ica_rpm"\
					"1"\
					"set_env icaclient_rpm_install"
			  	set waitvar 1
				vwait waitvar	
			}
		} else {
				get_dir "Where is the ICAClient RPM?"\
					"ica_rpm"\
					"1"\
					"set_env icaclient_rpm_install"
			  	set waitvar 1
				vwait waitvar
		}
        }
        Ftp { 
		set fi "$CFBUILD_DIR_NO_SLASH/Packages/ftp.tar.gz"
                if { [file exists $fi] } {
                        if {[confirm_ask "This package is already built.\nDo you want to build again?"]} {
                                set waitvar 0
				get_dir "Where is the FTP RPM?"\
	          			"ftp_rpm"\
		  			"1"\
		  			"set_env ftp_rpm_install"
	  			set waitvar 1
          			vwait waitvar
			}
		} else {
				get_dir "Where is the FTP RPM?"\
	          			"ftp_rpm"\
		  			"1"\
		  			"set_env ftp_rpm_install"
	  			set waitvar 1
          			vwait waitvar
		}
        }
        Telnet { 
		set fi "$CFBUILD_DIR_NO_SLASH/Packages/telnet.tar.gz"
                if { [file exists $fi] } {
                        if {[confirm_ask "This package is already built.\nDo you want to build again?"]} {
                                set waitvar 0
				get_dir "Where is the Telnet RPM?"\
	     				"telnet_rpm"\
		  			"1"\
		  			"set_env telnet_rpm_install"
	  			set waitvar 1
	  			vwait waitvar
			}
		} else {
				get_dir "Where is the Telnet RPM?"\
	     				"telnet_rpm"\
		  			"1"\
		  			"set_env telnet_rpm_install"
	  			set waitvar 1
	  			vwait waitvar
		}
	}
	FVWM2 {
		set fi "$CFBUILD_DIR_NO_SLASH/Packages/fvwm2.tar.gz"
                if { [file exists $fi] } {
                        if {[confirm_ask "This package is already built.\nDo you want to build again?"]} {
                                set waitvar 0
				get_dir "Where are the FVWM2 RPMs\n (main & icons) ?"\
					"fvwm2"\
		  			"2"\
		  			"set_env fvwm2_rpm_install"
	  			set waitvar 1
	  			vwait waitvar
			}
		} else {
				get_dir "Where are the FVWM2 RPMs\n (main & icons) ?"\
					"fvwm2"\
		  			"2"\
		  			"set_env fvwm2_rpm_install"
	  			set waitvar 1
	  			vwait waitvar
		}
	}
        Default { 
	  tk_messageBox -message $PACKAGE_UNDOCUMENTED
	  set waitvar 1
	  vwait waitvar
        }
      }
    }
	tk_messageBox -message $PACKAGE_BUILD_DONE
  }  
}

proc netscape_rpm_install {} {
  global waitvar
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting netscape_rpm_install"]
  flush $lh

  action_window "Building Netscape Package...\nPlease Wait." \
                "./netscape_rpm.sh"\
                "netscape_rpm.log"\
                "Build Complete"
  set waitvar 0
  return
}

proc ftp_rpm_install {} {
  global waitvar
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting ftp_rpm_install"]
  flush $lh

  action_window "Building Ftp Package...\nPlease Wait." \
		"./ftp_rpm.sh"\
		"ftp_rpm.log"\
		"Build Complete"
  set waitvar 0
  return
}

proc telnet_rpm_install {} {
  global waitvar
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting telnet_rpm_install"]
  flush $lh

  action_window "Building Telnet Package...\nPlease Wait." \
		"./telnet_rpm.sh"\
		"telnet_rpm.log"\
		"Build Complete"
  set waitvar 0
  return
}

proc icaclient_rpm_install {} {
  global waitvar
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting icaclient_rpm_install"]
  flush $lh

  action_window "Building ICAClient Package...\nPlease Wait." \
		"./icaclient_rpm.sh"\
		"icaclient_rpm.log"\
		"Build Complete"
  set waitvar 0
  return
}

proc fvwm2_rpm_install {} {
  global waitvar
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting fvwm2_rpm_install"]
  flush $lh

  action_window "Building FVWM2 Package...\nPlease Wait." \
		"./fvwm2_rpm.sh"\
		"fvwm2_rpm.log"\
		"Build Complete"
  set waitvar 0
  return
}
  
#.------------------------------------------------------------,
#| Huge beast that sets up the environment. prolly need to    |
#| clean this up sometime... =)                               |
#`------------------------------------------------------------'
#  SaveDirInfo $save_type $num_browse 

proc SaveDirInfo {type numvals} {
    global lh
    global a_path
    puts $lh [format "%s" "Starting SaveDirInfo"]
    puts $lh [format "%s:\n\t--%s\n\t--%s" "Passed Vars" "$type" "$numvals"]
    for {set x 0} {$x < $numvals} {incr x} {
	puts $lh [format "%s:\n\t--%s=%s" "Saving" "$type" "$a_path($x)"]
    }
    flush $lh

    global BOOTDIR
    global logfilename
    global NETSCAPE_ROOT
    global NETSCAPE_COMMON
    global NETSCAPE_NAVI
    global ICACLIENT_RPM
    global FTP_RPM
    global TELNET_RPM
    global FVWM2_SOURCE
    global FVWM2_ICON_SOURCE
    global CUSTOM_PACKAGE
    global INSTALL_DEST
    global INSTALL_SOURCE
    global BACKUP_SOURCE
    global RESTORE_SOURCE
    global CFBUILD_DIR_NO_SLASH
    global CFBUILD_DIR
    global CUSTOM_DIR
    global INSTALLDOC_DIR
    global SCRIPT_DIR

    if {$numvals >= 1} {

	switch $type {
	netscape_rpm {
		set NETSCAPE_COMMON "$a_path(0)"
		set NETSCAPE_NAVI "$a_path(1)"
	}
	ica_rpm {
		set ICACLIENT_RPM "$a_path(0)"
	}
	ftp_rpm {
		set FTP_RPM "$a_path(0)"
	}
	telnet_rpm {
		set TELNET_RPM "$a_path(0)"
	}
	custom_package {
		set CUSTOM_PACKAGE "$a_path(0)"
	}
	backup {
		set BACKUP_SOURCE "$a_path(0)"
	    }
	restore {
		set RESTORE_SOURCE "$a_path(0)"
	    }
	fvwm2 {
		set FVWM2_SOURCE "$a_path(0)"
		set FVWM2_ICON_SOURCE "$a_path(1)"
	    }
	}
    } ;# end if clause

    exec mkdir -p /root/IBM/
    set filename "/root/IBM/DirInfo"
    set fd [open $filename w]
    fconfigure $fd
    puts $fd [format "%s=%s" "bootdir" $BOOTDIR]
    puts $fd [format "%s=%s" "logfilename" $logfilename]
    puts $fd [format "%s=%s" "netscape_common" $NETSCAPE_COMMON]
    puts $fd [format "%s=%s" "netscape_navi" $NETSCAPE_NAVI]
    puts $fd [format "%s=%s" "icaclient_rpm" $ICACLIENT_RPM]
    puts $fd [format "%s=%s" "ftp_rpm" $FTP_RPM]
    puts $fd [format "%s=%s" "telnet_rpm" $TELNET_RPM]
    puts $fd [format "%s=%s" "install_dest" $INSTALL_DEST]
    puts $fd [format "%s=%s" "install_source" $INSTALL_SOURCE]
    puts $fd [format "%s=%s" "fvwm2_source" $FVWM2_SOURCE]
    puts $fd [format "%s=%s" "fvwm2_icon_source" $FVWM2_ICON_SOURCE]
    puts $fd [format "%s=%s" "backup_source" $BACKUP_SOURCE]
    puts $fd [format "%s=%s" "restore_source" $RESTORE_SOURCE]
    puts $fd [format "%s=%s" "cfbuild_dir" $CFBUILD_DIR_NO_SLASH] 
    puts $fd [format "%s=%s" "custom_dir" $CUSTOM_DIR]
    puts $fd [format "%s=%s" "installdoc_dir" $INSTALLDOC_DIR]
    puts $fd [format "%s=%s" "script_dir" $SCRIPT_DIR]

    close $fd
    exec chmod a+x /root/IBM/DirInfo
    exec sync  

}

