#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded NetVista ThinClient   |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: menubar.tcl                                      |
#| Last Modified: May 23, 2000 by Ryan Harper                 |
#| Changes:  added View License option under help             |
#|           added View Log option under Help                 |
#| Description: Builds the menuing system. Implemented as of  |
#|     version 2.3                                            |
#`------------------------------------------------------------'

#Builds the menuing system for the Compact Flash Builder
#  (CFBuilder). This menuing system is being implemented
#  as of version 2.1 of the program.
#Chris Glendenning 4/7/2000
#Ryan Harper Hacking 04.09.00
#Ryan Harper more hacking 06.28.00 - 

#-------------------MENU BAR----------------------------------------------- 

proc buildMenus {} {
	global MENU_FILE
	  global FILE_EXIT 
	global MENU_BUILD 
	  global BUILD_IMAGE 
	  global BUILD_PACKAGE 
	  global BUILD_SDF 
	global MENU_SETTINGS 
	  global SETTINGS_DISPLAY 
	  global SETTINGS_MANAGEMENT 
	  global SETTINGS_NETWORK 
	global MENU_SYSTEM 
	  global SYSTEM_WIZARD 
	  global SYSTEM_BASEOS
	global MENU_UTILITIES 
	  global UTILITIES_BACKREST
	  global UTILITIES_FORMAT 
	  global UTILITIES_MOUNT 
	  global UTILITIES_PARTITION 
	global MENU_HELP 
	  global HELP_ABOUT 
	  global HELP_LOG 
	  global HELP_LICENSE 
   
    global lh
    puts $lh [format "%s" "Creating Menu (buildMenus)"]
    flush $lh
    frame .menubar -height 18 -relief raised -borderwidth 2
    pack .menubar -side top -fill x

    #make background canvas and add logo image
    set c [canvas .c -width 545 -height 195 -relief sunken -bd 2]
    set image [image create photo -file CFBUILDER.GIF]
    $c create image 275 100 -image $image -tags item
    pack .c

    #Create menubutton .menubar.file with submenu .menubar.file.menu
    # --FILE--
    menubutton .menubar.file -text $MENU_FILE -menu .menubar.file.menu -underline 0
    menu .menubar.file.menu -tearoff 0
    pack .menubar.file -side left

    #Create menubutton .menubar.build with submenu .menubar.build.menu
    # --BUILD--
    menubutton .menubar.build -text $MENU_BUILD -menu .menubar.build.menu\
      -underline 0
    menu .menubar.build.menu -tearoff 0
    pack .menubar.build -side left

    #Create menubutton .menubar.settings with submenu .menubar.settings.menu
    # --SETTINGS--
    menubutton .menubar.settings -text $MENU_SETTINGS -menu .menubar.settings.menu\
      -underline 0
    menu .menubar.settings.menu -tearoff 0
    pack .menubar.settings -side left

    #Create menubutton .menubar.system with submenu .menubar.system.menu
    # --SYSTEM--
    menubutton .menubar.system -text $MENU_SYSTEM -menu .menubar.system.menu\
      -underline 0
    menu .menubar.system.menu -tearoff 0
    pack .menubar.system -side left

    #Create menubutton .menubar.utilities with submenu .menubar.utilities.menu
    # --UTILITIES--
    menubutton .menubar.utilities -text $MENU_UTILITIES\
      -menu .menubar.utilities.menu -underline 0
    menu .menubar.utilities.menu -tearoff 0
    pack .menubar.utilities -side left

    #Create menubutton .menubar.help with submenu .menubar.help.menu
    # --HELP--
    menubutton .menubar.help -text $MENU_HELP -menu .menubar.help.menu -underline 0
    menu .menubar.help.menu -tearoff 0
    pack .menubar.help -side right

    #Build the submenus

    #File submenu choices
    # --FILE->EXIT--
    .menubar.file.menu add command -label $FILE_EXIT -command {exit .} -underline 0\
      -accelerator "Ctrl+X"

    #Build submenu choices
    # --BUILD->IMAGE
    .menubar.build.menu add command -label $BUILD_IMAGE\
      -command {create_images "0"} -underline 0 -accelerator "Ctrl+I"
    # --BUILD->PACKAGES
    .menubar.build.menu add command -label $BUILD_PACKAGE\
      -command {create_packages "0"} -underline 0 -accelerator "Ctrl+P"

    #Settings submenu choices
    # --SETTINGS->DISPLAY
    .menubar.settings.menu add command -label $SETTINGS_DISPLAY\
      -command {choose_settings "0"} -underline 0 -accelerator "Ctrl+D"
    # --SETTINGS->MANAGEMENT
    .menubar.settings.menu add command -label $SETTINGS_MANAGEMENT\
      -command {choose_settings "0"} -underline 0 -accelerator "Ctrl+M"
    # --SETTINGS->NETWORK
    #      .menubar.settings.menu add command -label $SETTINGS_NETWORK\
      -command {MOO}  #	 -underline 0 -accelerator "Ctrl+N"

    #System submenu choices
    # --SYSTEM->Run Wizard
    .menubar.system.menu add command -label $SYSTEM_WIZARD -command {intro\
      "1"} -underline 0 -accelerator "Ctrl+W"
    .menubar.system.menu add command -label $SYSTEM_BASEOS -command {changeOS "0"} -underline 0 -accelerator "Ctrl+O"


    #Utilities submenu choices
    # --UTILITIES->BACKUP
    #.menubar.utilities.menu add command -label $UTILITIES_BACKREST\
    #  -command {backup_restore "0"} -underline 0 -accelerator "Ctrl+B"
    # --UTILITIES->FORMAT
    .menubar.utilities.menu add command -label $UTILITIES_FORMAT\
      -command {create_partition "0"} -underline 0 -accelerator "Ctrl+F"
    # --UTILITIES->MOUNT
    .menubar.utilities.menu add command -label $UTILITIES_MOUNT\
      -command {create_partition "0"} -underline 0 -accelerator "Ctrl+U"
    # --UTILITIES->PARTITION
    .menubar.utilities.menu add command -label $UTILITIES_PARTITION\
      -command {create_partition "0"} -underline 0 -accelerator "Ctrl+R"

    #Help submenu choices
    # --HELP->ABOUT
    .menubar.help.menu add command -label $HELP_ABOUT -command {showAbout}\
      -underline 0 -accelerator "F1"
    # --HELP->LogFile
    .menubar.help.menu add command -label $HELP_LOG -command {view_log}\
      -underline 0 -accelerator "F2"
    # --HELP->License
    .menubar.help.menu add command -label $HELP_LICENSE -command\
      {show_help_file "$CFBUILD_DIR_NO_SLASH/IPL" "IBM Corporation License"}\
      -underline 0 -accelerator "F3"

    if {[file exists /root/IBM/RunCFWiz]==0} {
	wm iconify .
	intro "1"
    }

}
#----------------------End MenuBar ---------------------------
