#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Thin Client     |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April, May 2000                                     |
#|                                                            |
#| Filename: wiz_buildimages.tcl                              |
#| Last Modified: August 22, 2000 by Ryan Harper              |
#| Changes: changed size to KB values 082200                  |
#|          Added Item Size array storage 07.21.00 RAH        |
#|          Added Create new Dir check 07.21.00 RAH           |
#|          Added Size of Flash Detection 07.21.00 RAH        |
#|          Added Package and Image Size functs 07.21.00 RAH  |
#|          Added Kernel selection,Update Flash 06.29.00 RAH  |
#| Description: New design for CF image building.  Reads in   |
#| all the files from /IBM/CFBuilder_X.X/Packages and allows  |
#| user to select which packages to unpack onto INSTALL_DIR.  |
#| This will facilitate installing to a Server Directory to   |
#| make Server Kiosk mode images, or Compact Flashes.         |
#`------------------------------------------------------------'

#.------------------------------------------------------------,
#| main procedure for building packages                       |
#|                                                            |
#| this proc starts up the build images panel.  It takes      |
#| show_next_back value to determine if it is being called in |
#| wizard mode or not, if in wiz mode, then shows the next and|
#| back buttons of the wizard mode.                           |
#`------------------------------------------------------------'
proc create_images {show_next_back} {
  global packageSize
  global INSTALL_DIR
  global IMAGE_TITLE 
  global IMAGE_MAIN 
  global IMAGE_AVAIL_LIST 
  global IMAGE_INSTALL_DIR 
  global IMAGE_NEWIMAGE 
  global IMAGE_KERNEL 
  global IMAGE_PSIZE 
  global IMAGE_ISIZE 

  #---check to see if this panel is already up-------
  check_for_win {.win}

  #---get global log file handle and do some logging-
    global lh
    puts $lh [format "%s" "Starting build_packages"]
    puts $lh [format "%s=%s" "Running_in_Wizmode" "$show_next_back"]
    flush $lh

  #---destroy duplicate windows----------------------
    if {[winfo exists .win]} {
	wm deiconify .win
	return
    }

  #---set win size,title,focus, and center win-------
    set win [toplevel .win -width 700 -height 350]
    wm title .win $IMAGE_TITLE
    focus -force .win
    wm resizable .win 0 0
    centerwin .win

    #---bottom separator-----------------------------
    frame .win.sep -width 700 -height 2 -borderwidth 1 -relief sunken
    place .win.sep -x 0 -y 300
   
    #---add wizard buttons if show_next_back set-----
    if {$show_next_back} {
	button .win.next -text {Next >} -command {ChangePage\
	  "choose_settings" "1"}
	button .win.back -text {< Back} -command {ChangePage "create_partition" "1"}
	place .win.back -x 8 -y 310
	place .win.next -x 85 -y 310
    }

  #---Mount up flash for burning image
  cf_mount

  #---Main instructional message--------------------
  label .win.lMain -text $IMAGE_MAIN
  place .win.lMain -x 10 -y 10


  #---Available Packages Listbox--------------------
  label .win.lAvail -text $IMAGE_AVAIL_LIST
  place .win.lAvail -x 10 -y 50
  listbox .win.lbAvail -width 40 -height 8 -background "white"\
   -selectmode "multiple" -yscrollcommand ".win.sbAvail set"
  place .win.lbAvail -x 10 -y 70
  scrollbar .win.sbAvail -command ".win.lbAvail yview"
  place .win.sbAvail -x 298 -y 70 -height 142

  #---Packages to install Listbox-------------------
  label .win.lBuild -text $IMAGE_INSTALL_DIR
  place .win.lBuild -x 382 -y 50
  entry .win.eInstallPath -width "28"
  place .win.eInstallPath -x 467 -y 48

  #--- set default entry to INSTALL_DIR
  .win.eInstallPath insert end $INSTALL_DIR

  bind .win.eInstallPath <Leave> { checkDir }

  proc checkDir {} {
	global INSTALL_DIR
	if {[check_for_win .mkdir]} {
	} else {
		set test 0
		if {[file isdirectory [.win.eInstallPath get]] == 0} {
			set test [askMkdir]
			destroy .mkdir
	 	}
	}
  }

  proc askMkdir {} {
	global IMAGE_NEWDIR_TITLE
	global IMAGE_NEWDIR
	global IMAGE_NEWDIR_YES
	global IMAGE_NEWDIR_NO
	set pathitem [.win.eInstallPath get]
	set value 0

	toplevel .mkdir -width 200 -height 120
	wm resizable .mkdir 0 0
	wm title .mkdir $IMAGE_NEWDIR_TITLE
	label .mkdir.message -text $IMAGE_NEWDIR
	place .mkdir.message -x 8 -y 10
	button .mkdir.yes -text $IMAGE_NEWDIR_YES -command {file mkdir [.win.eInstallPath get]; set value 1}
	button .mkdir.no -text $IMAGE_NEWDIR_NO -command {set value 0}
	place .mkdir.yes -x 50 -y 60
	place .mkdir.no -x 100 -y 60
	centerwin .mkdir

	vwait value
	return $value
  }

  listbox .win.lbBuild -width 40 -height 8 -background "white"\
   -selectmode "multiple" -yscrollcommand ".win.sbBuild set"
  place .win.lbBuild -x 382 -y 70
  scrollbar .win.sbBuild -command ".win.lbBuild yview"
  place .win.sbBuild -x 670 -y 70 -height 142

  #---Install Options--------------------------------
  #--- option values: 1 = install second partition tar, includes NetworkAddress and SetupInfoBlock
  #--- 		      0 = updating, do not install second part tar..., already there
  global option
  set option 1
  checkbutton .win.cbOption -offvalue 0 -onvalue 1 -variable option 
  label .win.lCheckInstall -text $IMAGE_NEWIMAGE
  place .win.cbOption -x 600 -y 260
  place .win.lCheckInstall -x 620 -y 260
  .win.cbOption select
  
  #---Target Machine Option--------------------------
  #--- Choice between what kernels to include, 2800, 2200, or both
  global include2800
  global include2200
  set include2800 1
  set include2200 1
  checkbutton .win.cb2800 -offvalue 0 -onvalue 1 -variable include2800
  checkbutton .win.cb2200 -offvalue 0 -onvalue 1 -variable include2200
  label .win.linclude2800 -text "2800"
  label .win.linclude2200 -text "2200"
  label .win.ltarget -text $IMAGE_KERNEL

  place .win.ltarget -x 10 -y 260
  place .win.cb2800 -x 115 -y 260
  place .win.linclude2800 -x 135 -y 260
  place .win.cb2200 -x 170 -y 260
  place .win.linclude2200 -x 190 -y 260
  .win.cb2800 select
  .win.cb2200 select

  #---Listbox buttons--------------------------------
  button .win.bAddtoBuild -width 1 -text "->" -command AddtoBuild
  place .win.bAddtoBuild -x 335 -y 100

  button .win.bRemovefromBuild -width 1 -text "<-" -command RemovefromBuild
  place .win.bRemovefromBuild -x 335 -y 130

  button .win.bAddtoAvail -width 3 -text "Add" -command addItem
  place .win.bAddtoAvail -x 382 -y 260

  button .win.bBuild -width 4 -text "Build" -command BuildList
  place .win.bBuild -x 442 -y 260

  #---Package Size-----------------------------------
  label .win.packagesize -text $IMAGE_PSIZE
  place .win.packagesize -x 10 -y 215
  bind .win.lbAvail <ButtonRelease> { fileInfo }
  proc fileInfo {} {
	global packageSize
	if {[llength [.win.lbAvail curselection]] > 0 } {
		set file [.win.lbAvail get [lindex [.win.lbAvail curselection] 0]]
		if {[file exists $file]} {
			.win.packagesize configure -text "Package Size: [expr [lindex [array get packageSize $file] 1] / 1024 ] KB"
		}
	}
  }

  proc getSizeFromArray { file } {
	global packageSize

	set searchlist [array get packageSize $file]
	if {[llength $searchlist]>1} {
		return [lindex $searchlist 1]
	} else {
		set size [getSize $file]
		array set packageSize [list $file $size]
		return $size
	}
  }

  #---Image Size-------------------------------------
  label .win.imagesize -text $IMAGE_ISIZE
  place .win.imagesize -x 382 -y 215
  bind .win.lbBuild <ButtonRelease> { imageInfo }
  bind .win.cb2800 <ButtonRelease> { imageInfo }
  bind .win.cb2200 <ButtonRelease> { imageInfo }
  proc imageInfo {} {
	global include2800
	global include2200
	checkDir
	set isize 0
	set fsize [getFlashSize [.win.eInstallPath get]]
	if { $include2800 } {
		set isize [expr [expr [file size "/kernel.2800"] / 1024 ] + $isize]
	}
	if { $include2200 } {
		set isize [expr [expr [file size "/kernel.2200"] / 1024 ] + $isize]
	}
	if {[llength [.win.lbBuild size]] > 0} {
		for {set x 0} {$x < [.win.lbBuild size]} {incr x} {
			if {[file exists [.win.lbBuild get $x]]} {
				set isize [expr $isize + [expr [getSizeFromArray [.win.lbBuild get $x]] / 1024 ]] 
			}
		}
	.win.imagesize configure -text "Image Size: $isize KB / $fsize KB"
	}
	if {[expr $isize > $fsize]} { 
		.win.imagesize configure -foreground "red"
		.win.bAddtoBuild configure -state disabled
		.win.bAddtoAvail configure -state disabled
		.win.bBuild configure -state disabled
	} else {
		.win.imagesize configure -foreground "black"
		.win.bAddtoBuild configure -state normal
		.win.bAddtoAvail configure -state normal
		.win.bBuild configure -state normal

	}

  }
  imageInfo

  #---Listbox fill functions-------------------------
  readImages

}

#.------------------------------------------------------------,
#| Read list of packages file and populate listbox            |
#|                                                            |
#| this proc takes no args, reads the                         |
#|      /IBM/CFBuilder_X.X/Packages directory                 |
#| The files in the directory will populate the Avail list and|
#| the user can add their own files, tar.gz,tar, and rpm files|
#| with the Add Package button.	                              |
#`------------------------------------------------------------'
proc readImages {} {
  global packageSize
  global CFBUILD_DIR_NO_SLASH 	;# global var that has path to program

  #---get global log file handle and do some logging-
    global lh
    puts $lh [format "%s" "Starting readImages"]
    flush $lh


	focus -force .win

	#--- open dummy file to get a list of files in Packages dir
	set listname "$CFBUILD_DIR_NO_SLASH/Packages/.plist"

	#--- keep current dir, change back when done.
	set currentdir [pwd]
	
	#--- Change to Packages dir to get listing
	cd $CFBUILD_DIR_NO_SLASH/Packages/

	#--- do ls and redirect stdout to file .plist
	exec ls > .plist

	#--- cd back to orig dir
	cd $currentdir

	#--- open .plist to read output
	set plh [open $listname r]
	
	#--- for each value in file, add to Avail listbox, append full path
	while {[gets $plh plist] > 0} {
            #---get global log file handle and do some logging- @RHG
            global lh
            puts $lh [format "%s %s" "Read from plist" $plist]
            flush $lh

		.win.lbAvail insert end $CFBUILD_DIR_NO_SLASH/Packages/$plist
		array set packageSize [list $CFBUILD_DIR_NO_SLASH/Packages/$plist [getSize $CFBUILD_DIR_NO_SLASH/Packages/$plist]]
	}
	close $plh
	
	#--- clean up .plist file
	exec rm $CFBUILD_DIR_NO_SLASH/Packages/.plist
}


#.------------------------------------------------------------,
#|  proc called with user hits the Add button.  Uses get_dir  |
#| to call up a Modal dialog asking for the path file.        |
#`------------------------------------------------------------'
proc addItem {} {
  global IMAGE_ADDITEM_GET
  #--- call get_dir, pass in First message, Save Type, Number of file boxes, and command to
  #--- run after getting file.
  checkDir
  get_dir $IMAGE_ADDITEM_GET "tar" "1" "insertItem"
}


#.------------------------------------------------------------,
#|  insertItem tests the file type in the global var a_path(0)|
#|  if it is a type supported, tar.gz,tar,rpm,tgz,Z, then add |
#|  it to the Install list.
#`------------------------------------------------------------'
proc insertItem {trash num} {
  global IMAGE_FILETYPE_NOSUPPORT
  global IMAGE_SELECTFILE
  global a_path  	;#--- global var that holds path to file
  global i		;#--- global index into a_path

  #---get global log file handle and do some logging-
    global lh
    puts $lh [format "%s" "Starting insertItem"]
    flush $lh
	
	#--- make sure user selects something
	if {[string length $a_path(0)] > 0} {
		set package_name [string tolower $a_path(0)]

		#--- test package_name extension, if supported, add to Install path
		if {[string match ".gz" [file extension $package_name] ]} {
			.win.lbBuild insert end $a_path(0)
			destroy .win.top
		} elseif {[string match ".rpm" [file extension $package_name] ]} {
			.win.lbBuild insert end $a_path(0)
			destroy .win.top
		} elseif {[string match ".tar" [file extension $package_name] ]} {
			.win.lbBuild insert end $a_path(0)
			destroy .win.top
		} elseif {[string match ".tgz" [file extension $package_name] ]} {
			.win.lbBuild insert end $a_path(0)
			destroy .win.top
		} elseif {[string match ".z" [file extension $package_name] ]} {
			.win.lbBuild insert end $a_path(0)
			destroy .win.top
		} else {
			tk_messageBox -message $IMAGE_FILETYPE_NOSUPPORT ;# ERROR CODE 001
			set i [expr $i - 1]
		}
		set a_path(0) ""
	} else {
		tk_messageBox -message $IMAGE_SELECTFILE ;# ERROR CODE 002
	}
  imageInfo
  return
}

#.------------------------------------------------------------,
#| proc to add items from Avail list to Install list. for each|
#| item selected, add to Install list.  Doest not check for   |
#| duplicates.						      |
#`------------------------------------------------------------'
proc AddtoBuild {} {
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting AddtoBuild"]

  foreach x [.win.lbAvail curselection] { 
	.win.lbBuild insert end [.win.lbAvail get $x]
  }
  foreach x [lsort -decreasing [.win.lbAvail curselection]] { .win.lbAvail delete $x }
  flush $lh
  .win.lbAvail selection clear 0 end
  imageInfo

}

#.------------------------------------------------------------,
#| proc to remove items from Install list. for each item      |
#| selected, remove from Install list in reverse order.       |
#`------------------------------------------------------------'
proc RemovefromBuild {} {
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting RemovefromBuild"]
  flush $lh
  foreach x [.win.lbBuild curselection] { 
	.win.lbAvail insert end [.win.lbBuild get $x]
  }
  foreach x [lsort -decreasing [.win.lbBuild curselection]] { .win.lbBuild delete $x }
  imageInfo
}

#.------------------------------------------------------------,
#| BuildList reads the items in the right side listbox, for   |
#| each item in list, untar, or rpm install, or gunzip into   |
#| INSTALL_DIR, read from entry box, based on file extention. |
#`------------------------------------------------------------'
proc BuildList {} {
  global IMAGE_EMPTY_BUILD
  global IMAGE_EXT_NOSUPPORT
  global IMAGE_BUILD_DONE
  global IMAGE_NO_WINDOW_MANAGER
  global option
  global include2800
  global include2200
  global waitvar
  global show_next_back

  checkDir

  #---get global log file handle and do some logging-
    global lh
    puts $lh [format "%s" "Starting BuildList"]
    flush $lh

  #--- get a list of items in the Install list
  set itemlist [.win.lbBuild get 0 [.win.lbBuild size]]

  #--- when making a new image, i.e. New Image check box is set to
  #--- TRUE, then search list for fvwm2 package, if not there generate error and
  #--- stop build op. 

  if { $option } {
	set fvwm2found 0
	foreach x $itemlist {
		if { [string last "fvwm2" $x] > 0 } {
			set fvwm2found 1
		}
	}
	
	if { $fvwm2found == 0 } {
		tk_messageBox -message $IMAGE_NO_WINDOW_MANAGER  ;# ERROR CODE 003
		return
	}

  }
  

  #--- if there arent any in the list, catch error.
  if {[llength $itemlist] <= 0} {
    tk_messageBox -message $IMAGE_EMPTY_BUILD
  } else {
	foreach x $itemlist {
		switch [file extension $x] {
			.gz {
				unpack_gz [.win.eInstallPath get] $x
			}
			.rpm {
				unpack_rpm [.win.eInstallPath get] $x
			}
			.tar {
				unpack_tar [.win.eInstallPath get] $x
			}
			.tgz {
				unpack_gz [.win.eInstallPath get] $x
			}
			.Z {
				unpack_z [.win.eInstallPath get] $x
			}
			default {
				tk_messageBox -message "$IMAGE_EXT_NOSUPPORT $x" ;# ERROR CODE 005
			}
		}
	} ;# end of foreach

        # test kernel options, copy selected kernels to INSTALL_DIR
	copy_kernels

	# test new image option, if selected, copy second partition tar onto /mnt/hd2, 
	# note:, if doing a server kiosk mode, will copy 2nd part to  /mnt/hd2, regardless
	add2ndPart
	tk_messageBox -message $IMAGE_BUILD_DONE
  }
}

#.------------------------------------------------------------,
#|  Helper functions that are called to process different file|
#| types.  Each helper function takes the INSTALL_DIR value   |
#| and th full path to file (package), and writes a script    |
#| with the commands needed to install (package) to  	      |
#| INSTALL_DIR.						      |
#|							      |
#| Helper Functions:                                          |
#|	unpack_gz, unpack_tgz, unpack_rpm,unpack_tar,unpack_z |
#`------------------------------------------------------------'
proc unpack_gz {install_dir package} {
	global CFBUILD_DIR_NO_SLASH
	global waitvar
	#---get global log file handle and do some logging-
	global lh
	puts $lh [format "%s" "Starting unpack_gz"]
	puts $lh [format "%s %s %s" "Passed Vars:" "Install Dir: $install_dir" "Package: $package"]
	flush $lh

	set filename "$CFBUILD_DIR_NO_SLASH/Scripts/custom_gz.sh"
	set fd [open $filename w]
	fconfigure $fd
	puts $fd "#! /bin/sh"
	puts $fd ". /root/IBM/DirInfo"
	puts $fd "mkdir -p $install_dir"
	puts $fd "cd $install_dir"
	puts $fd "tar -xzvf $package 2> /dev/null"
	puts $fd "sync"
	close $fd
	exec chmod a+x $CFBUILD_DIR_NO_SLASH/Scripts/custom_gz.sh
	exec sync

	action_window "Installing $package...\nPlease Wait." \
		"./custom_gz.sh"\
		"custom_gz.log"\
		"Installation Complete"

	set waitvar 0
	return
}

proc unpack_rpm {install_dir package} {
	global CFBUILD_DIR_NO_SLASH
	global waitvar
	#---get global log file handle and do some logging-
	global lh
	puts $lh [format "%s" "Starting unpack_rpm"]
	puts $lh [format "%s %s %s" "Passed Vars:" "Install Dir: $install_dir" "Package: $package"]
	flush $lh

	set filename "$CFBUILD_DIR_NO_SLASH/Scripts/custom_rpm.sh"
	set fd [open $filename w]
	fconfigure $fd
	puts $fd "#! /bin/sh"
	puts $fd ". /root/IBM/DirInfo"
	puts $fd "mkdir -p $install_dir"
	puts $fd "cd $install_dir"
	puts $fd "ln -sf /var var"
	puts $fd "rpm -i --excludedocs --force --nodeps --root $install_dir $package"
	puts $fd "rm var"
	puts $fd "sync"
	close $fd
	exec chmod a+x $CFBUILD_DIR_NO_SLASH/Scripts/custom_rpm.sh
	exec sync

	action_window "Installing $package...\nPlease Wait." \
		"./custom_rpm.sh"\
		"custom_rpm.log"\
		"Installation Complete"

	set waitvar 0
	return
}

proc unpack_tar {install_dir package} {
	global CFBUILD_DIR_NO_SLASH
	global waitvar
	#---get global log file handle and do some logging-
	global lh
	puts $lh [format "%s" "Starting unpack_tar"]
	puts $lh [format "%s %s %s" "Passed Vars:" "Install Dir: $install_dir" "Package: $package"]
	flush $lh

	set filename "$CFBUILD_DIR_NO_SLASH/Scripts/custom_tar.sh"
	set fd [open $filename w]
	fconfigure $fd
	puts $fd "#! /bin/sh"
	puts $fd ". /root/IBM/DirInfo"
	puts $fd "mkdir -p $install_dir"
	puts $fd "cd $install_dir"
	puts $fd "tar -xvf $package 2> /dev/null"
	puts $fd "sync"
	close $fd
	exec chmod a+x $CFBUILD_DIR_NO_SLASH/Scripts/custom_tar.sh
	exec sync

	action_window "Installing $package...\nPlease Wait." \
		"./custom_tar.sh"\
		"custom_tar.log"\
		"Installation Complete"

	set waitvar 0
	return
}

proc unpack_z {install_dir package} {
	global CFBUILD_DIR_NO_SLASH
	global waitvar
	#---get global log file handle and do some logging-
	global lh
	puts $lh [format "%s" "Starting unpack_z"]
	puts $lh [format "%s %s %s" "Passed Vars:" "Install Dir: $install_dir" "Package: $package"]
	flush $lh

	set filename "$CFBUILD_DIR_NO_SLASH/Scripts/custom_z.sh"
	set fd [open $filename w]
	fconfigure $fd
	puts $fd "#! /bin/sh"
	puts $fd ". /root/IBM/DirInfo"
	puts $fd "mkdir -p $install_dir"
	puts $fd "cd $install_dir"
	puts $fd "gunzip $package"
	puts $fd "sync"
	close $fd
	exec chmod a+x $CFBUILD_DIR_NO_SLASH/Scripts/custom_z.sh
	exec sync

	action_window "Installing $package...\nPlease Wait." \
		"./custom_z.sh"\
		"custom_z.log"\
		"Installation Complete"

	set waitvar 0
	return
}

proc copy_kernels {} {
        global CFBUILD_DIR_NO_SLASH
	global include2800
	global include2200
	global lh
	puts $lh [format "%s" "Starting copy_kernels"]
	flush $lh

	if { $include2800 } {
		puts $lh "Adding kernel.2800 to: [.win.eInstallPath get]"
		flush $lh
		exec cp -a /kernel.2800 [.win.eInstallPath get]
	}

	if { $include2200 } {
		puts $lh "Adding kernel.2200 to: [.win.eInstallPath get]"
		flush $lh
		exec cp -a /kernel.2200 [.win.eInstallPath get]
	}
}

proc add2ndPart {} {
	global option
	global CFBUILD_DIR_NO_SLASH
	global lh
	puts $lh [format "%s" "Starting add2ndPart"]

	if { $option } {
		puts $lh "Adding NetworkAddresses and IBMSetupInformationBlock to /mnt/hd2"
		flush $lh
		set orig [pwd]
		cd /mnt/hd2
		exec tar -xzf $CFBUILD_DIR_NO_SLASH/Custom/eLinux_partition2.tar.gz
		cd $orig
	}
}

proc getSize {fileName} {
# TODO: add parsecode to pull size value out of .sizeout file
#       see if you can spawn a process, so, not to disturb main
	global IMAGE_GETSIZE

	toplevel .size -width 200 -height 80
	wm resizable .size 0 0
	wm title .size "Reading Tar Size"
	label .size.message -text $IMAGE_GETSIZE
	place .size.message -x 50 -y 20
	centerwin .size
	update

  #---get global log file handle and do some logging- @RHG
    global lh
    puts $lh [format "%s %s" "Get Size for " $fileName]
    flush $lh

	switch [file extension $fileName] {
			.gz {
				exec tar -tzvf $fileName  >& /tmp/.sizeout.tmp
                                # Fix future date problem with tar command
				exec grep -v contains /tmp/.sizeout.tmp  >& /tmp/.sizeout
				set tsize [tarSize]
                             #---get global log file handle and do some logging- @RHG
                             global lh
                             puts $lh [format "%s %s" " Size calc. complete " $tsize]
                             flush $lh
				destroy .size
				return $tsize
			}
			.rpm {
				exec rpm -qpi $fileName >& /tmp/.sizeout
				set rsize [rpmSize]
                             #---get global log file handle and do some logging- @RHG
                             global lh
                             puts $lh [format "%s %s" " Size calc. complete " $rsize]
                             flush $lh
				destroy .size			
				return $rsize
			}
			.tar {
				exec tar -tvf $fileName  >& /tmp/.sizeout.tmp
                                # Fix future date problem with tar command
				exec grep -v contains /tmp/.sizeout.tmp  >& /tmp/.sizeout
				set tsize [tarSize]
                             #---get global log file handle and do some logging- @RHG
                             global lh
                             puts $lh [format "%s %s" " Size calc. complete " $tsize]
                             flush $lh
				destroy .size
				return $tsize
			}
			.tgz {
				exec tar -tzvf $fileName  >& /tmp/.sizeout.tmp
                                # Fix future date problem with tar command
				exec grep -v contains /tmp/.sizeout.tmp  >& /tmp/.sizeout
				set tsize [tarSize]
                             #---get global log file handle and do some logging- @RHG
                             global lh
                             puts $lh [format "%s %s" " Size calc. complete " $tsize]
                             flush $lh
				destroy .size
				return $tsize
			}	
			.Z {

			}
			default {
				tk_messageBox -message $IMAGE_EXT_NOSUPPORT ;# ERROR CODE 006
			}
		}
}

proc rpmSize {} {
	global sfh

	set sfh [open "/tmp/.sizeout" r]
	set item(0) 0;

	gets $sfh line ;# get line 1
	gets $sfh line ;# get line 2
	gets $sfh line ;# get line 3
	gets $sfh line ;# get line 4
	gets $sfh line ;# get line 5
	gets $sfh line ;# get line 6

	set sline [split $line]
	set counter 0

	foreach x $sline {
		if {[string length $x]>0} {
			set item($counter) $x
			incr counter
		}	
	}

	return $item(2)
}

proc tarSize {} {
	global sfh
	set record 0
	global bob
	set totalsize 0
	set sfh [open "/tmp/.sizeout" r]



	while {[gets $sfh line]>0} {
		global bob
		set sline [split $line]
		set counter 0

		foreach x $sline {
			if {[string length $x]>0} {
				set bob($record,$counter) $x
				incr counter
			}
		}
		incr record
	}

	for {set i 0} {$i < $record} {incr i} {
		set totalsize [expr $totalsize + $bob($i,2)]
	}

	return $totalsize
}

proc getFlashSize { install_dir } {
  if {[file isdirectory $install_dir]} {
	exec /IBM/bin/IBMdf $install_dir > /tmp/.fsize

	set fh [open "/tmp/.fsize" r]
	set arr(0) 0

	gets $fh line
	gets $fh line

	set sline [split $line]
	set count 0

	foreach x $sline {
		if {[string length $x]>0} {
			set arr($count) $x
			incr count
		}
	}

	return $arr(3)
  }
	return 0
}
