#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Thin Client     |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April, May 2000                                     |
#|                                                            |
#| Filename: wiz_packages.tcl                                 |
#| Last Modified: June 27, 2000 by Ryan Harper                |
#| Changes:                                                   |
#| Description: New design for package building.  Builds all  |
#| packages before burning Compact Flash, added building base |
#| OS tar file and window manager tar file, that way, when    |
#| burning image, the baseOS and WM, are not built again.     |
#`------------------------------------------------------------'

#.------------------------------------------------------------,
#| main procedure for building packages                       |
#|                                                            |
#| this proc starts up the build packages panel.  It takes    |
#| show_next_back value to determine if it is being called in |
#| wizard mode or not, if in wiz mode, then shows the next and|
#| back buttons of the wizard mode.                           |
#`------------------------------------------------------------'
proc create_packages {show_next_back} {
  global PACKAGE_TITLE
  global PACKAGE_MAIN
  global mode $show_next_back
  #---check to see if this panel is already up-------
  check_for_win {.win}

  #---get global log file handle and do some logging-
    global lh
    puts $lh [format "%s" "Starting create_packages"]
    puts $lh [format "%s=%s" "Running_in_Wizmode" "$show_next_back"]
    flush $lh

  #---destroy duplicate windows----------------------
    if {[winfo exists .win]} {
	wm deiconify .win
	return
    }

  #---set win size,title,focus, and center win-------
    set win [toplevel .win -width 400 -height 300]
    wm title .win $PACKAGE_TITLE
    wm geometry .win 400x310+312+134
    focus -force .win
    wm resizable .win 0 0
    centerwin .win

    #---bottom separator-----------------------------
    frame .win.sep -width 400 -height 2 -borderwidth 1 -relief sunken
    place .win.sep -x 0 -y 260
   
    #---add wizard buttons if show_next_back set-----
    if {$show_next_back} {
	button .win.next -text {Next >} -command {ChangePage\
	  "create_partition" "1"}
	button .win.back -text {< Back} -command {ChangePage "intro" "1"}
	place .win.back -x 8 -y 270
	place .win.next -x 85 -y 270
    }

  #---Main instructional message--------------------
  label .win.lMain -justify "left" -text $PACKAGE_MAIN
  place .win.lMain -x 10 -y 10

  #---Available Packages Listbox--------------------
  listbox .win.lbAvail -width 20 -height 8 -background "white"\
   -selectmode "multiple" -yscrollcommand ".win.sbAvail set"
  place .win.lbAvail -x 10 -y 80
  scrollbar .win.sbAvail -command ".win.lbAvail yview"
  place .win.sbAvail -x 158 -y 80 -height 142

  #---Packages to be built Listbox-------------------
  listbox .win.lbBuild -width 20 -height 8 -background "white"\
   -selectmode "multiple" -yscrollcommand ".win.sbBuild set"
  place .win.lbBuild -x 222 -y 80
  scrollbar .win.sbBuild -command ".win.lbBuild yview"
  place .win.sbBuild -x 370 -y 80 -height 142

  #---Listbox buttons--------------------------------
  button .win.bAddtoBuild -width 1 -text "->" -command pAddtoBuild
  place .win.bAddtoBuild -x 185 -y 110

  button .win.bRemovefromBuild -width 1 -text "<-" -command pRemovefromBuild
  place .win.bRemovefromBuild -x 185 -y 140

  button .win.bInfo -width 4 -text "Help" -command pPackInfo
  place .win.bInfo -x 10 -y 225

  button .win.bBuild -width 4 -text "Build" -command pBuildList
  place .win.bBuild -x 222 -y 225

  #---Listbox fill functions-------------------------
  readPackages
  insertPackList

}

#.------------------------------------------------------------,
#| Read list of packages file and populate listbox            |
#|                                                            |
#| this proc takes no args, reads the                         |
#|      /IBM/CFBuilder_X.X/Custom/packages.txt                |
#| The file is in this format                                 |
#| <Package Name> <format> <Source dir>                       |
#| Package Name is what will appear in the Avail listbox,     |
#| format is the format of the file, rpm, tar, ...            |
#| Source dir is the default location of the file             |
#|                                                            |
#| This file is read into a global structure, packarray       |
#`------------------------------------------------------------'
proc readPackages {} {
  global CFBUILD_DIR_NO_SLASH 	;# global var that has path to program
  global packarray 		;# make struct global
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting readPackages"]
  flush $lh

  #---set filename and handle
  set fnPackages "$CFBUILD_DIR_NO_SLASH/Custom/packages.txt"
  set fhPackages [open $fnPackages r]
  
  #--- set dummy count var
  set g 0

  #--- while there is a line in the file, grab it, and split is on
  #--- white space, this grabs the <Packname> <format> <source> for
  #--- the struct
  while {[gets $fhPackages packs] > 0} {
    set parsed [split $packs]
  #--- lindex gets the split values out of a list, 0 is first element of list
    set packarray($g.name) [lindex $parsed 0]
    set packarray($g.format) [lindex $parsed 1]
    set packarray($g.source) [lindex $parsed 2]
    incr g
  }
  #--- copy number of items from file to struct
  set packarray(size) $g
  close $fhPackages
}

#.------------------------------------------------------------,
#| Inserts items from packarray into listbox                  |
#|                                                            |
#| takes the Name field from packarry and inserts it into the | 
#| Avail listbox                                              |
#`------------------------------------------------------------'
proc insertPackList {} {
  global packarray
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting insertPackList"]
  flush $lh

  for { set g 0 } {$g < $packarray(size)} {incr g} {
    .win.lbAvail insert end $packarray($g.name)
  }
}

proc pAddtoBuild {} {
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting pAddtoBuild"]
  flush $lh
  global packarray
  foreach x [.win.lbAvail curselection] { .win.lbBuild insert end [.win.lbAvail get $x] }
  foreach x [lsort -decreasing [.win.lbAvail curselection]] { .win.lbAvail delete $x }
}


#--- possible dupe code, check wiz_buildimage.tcl
proc pRemovefromBuild {} {
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting pRemovefromBuild"]
  flush $lh
  global packarray
  foreach x [.win.lbBuild curselection] { .win.lbAvail insert end [.win.lbBuild get $x] }
  foreach x [lsort -decreasing [.win.lbBuild curselection]] { .win.lbBuild delete $x }
}

#--- --------------
#--- Helper procs to prevent package building from overlapping.  I.e. if user selects
#--- BaseOS, Netscape, and ICA, we dont want to try to install all 3 simultaneously.
#--- Hence the global waitvar and vwait call in pBuildList.
#--- --------------

proc set_env {script_cmd type num_browse} {
  global waitvar
  #---get global log file handle and do some logging-
  global lh
  puts $lh [format "%s" "Starting set_env"]
  puts $lh [format "%s %s %s %s" "Passed Vars:" "Script_cmd: $script_cmd" "Save Type: $type" "Number of entry boxes: $num_browse"]
  flush $lh

   SaveDirInfo $type $num_browse
   destroy .win.top
   $script_cmd

  return
}

#--- --------------
#--- NOTE: BaseOSInstall and the BaseOS switch do not need to use the global waitvar 
#--- and vwait.  
#--- --------------

proc BaseOSInstall {} {
	global waitvar
	toplevel .top -width 250 -height 150
	wm resizable .top 0 0
	wm title .top " "
	label .top.message -text "Building Base OS Package..."
	pack .top.message -padx 50 -pady 50
	wm geometry .top +360+340
	update idletasks
	buildBaseTar
	.top.message configure -text "Build Complete"
	after 1000
	destroy .top
	set waitvar 0
	return
}

########################################################################
#========================Base OS Build ================================#
#--- Main script to make base.tar.gz package			       #
########################################################################

proc buildBaseTar {} {
    global PACKAGE_BASEOS_COPY_ERRORS
    global BASEOS_FILELIST
    set BASEOS_FILELIST "BaseTarFileList.txt"
    global lh
    puts $lh [format "%s" "Starting buildBaseTar"]
    flush $lh

    global CFBUILD_DIR
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR

    global BOOTDIR

    exec mkdir -p $CFBUILD_DIR_NO_SLASH/basetemp
    set HOME "$CFBUILD_DIR_NO_SLASH/basetemp"
    exec cp -a $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/$BASEOS_FILELIST $HOME
    exec cp -a $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/make_base_dirs.sh $HOME

    cd $HOME

    set filelistloc "./$BASEOS_FILELIST"
    set ferrorloc "./errors.txt"

    exec ./make_base_dirs.sh 2> make_base.log

    if {[file exists $filelistloc]} {

	set fd [open $filelistloc r]
	set ferror [open $ferrorloc w]
	#init badcopy to be false
	set badcopy false

	#grab a string, check if we are at eof, then loop, grab another string


	if {[file exists $HOME/Validate] == 0} {
	    set counter 0
	    while {[gets $fd instring] > 0} {
		#make a list out of the string with source and path
		set pathlist [split $instring]

		#assign our strings for source and destination from the list
		set sourcefile [lindex $pathlist 0]
		set destpath [lindex $pathlist 1]

		#does the source exist and is the destination a directory?
		if {[file exists $sourcefile]} {
		    if {[file isdirectory $destpath]} {
			#copy our files
			file copy -force $sourcefile $destpath
		    } {
			file mkdir $destpath
			file copy -force $sourcefile $destpath
		    }
		    #if we get to this else the source file doesn't exist
		} {
		    set badcopy true
		    puts $ferror $sourcefile
		    puts $lh [format "%s" "Error copying file: $sourcefile"]
		    flush $lh
		}
	    } ;#end of the while loop

	} ;#end of if, skip copy if valid copy exists


	close $fd
	close $ferror

	if {$badcopy} {
	    tk_messageBox -title "Copy Errors" -message $PACKAGE_BASEOS_COPY_ERRORS ;# ERROR CODE 007
	} {
	    file delete $ferror
	    #we know our copy went through successfully so lets make our tar!
	    puts $lh [format "%s" "BaseOS Copy Sucess!"]
	    flush $lh
	    cd $HOME
	    exec touch Validate
	    if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz] == 0} {
		cd $CFBUILD_DIR
		.top.message configure -text "Building BaseOS"
		update
		puts $lh [format "%s" "Executing: $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/base_tarbuilder.sh"]
	    	flush $lh
		exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/base_tarbuilder.sh
		.top.message configure -text "Build Complete"
		update
		return
	    }
	    return
	}

    } {
	puts $lh [format "%s" "Error: $BASEOS_FILELIST was not found. Check $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/."]
	flush $lh
	tk_messageBox -title Error -message "$BASEOS_FILELIST not found. Aborting execution." ;# ERROR CODE 008
    }
    return
}
