#!/bin/ksh
#set -x

# InstallFlashImage.sh
# 
# Start up script that will query user for a bootserver and
# mount point, mount the server, look for FlashImages, (IDFs)
# and present a list of the IDFs and prompt the user to select
# which image they want to install to their flash. Once an 
# image is selected, it will call a script to partition, format
# and mount the flash to /mnt/hd1, and then call "lcma", the
# update binary to update the mounted flash with the IDF the
# user selected.
#
#



function getBootServer 
{
	echo -n "What is the IP of your bootserver?: "; read -r BOOTSERVER
	check_valid $BOOTSERVER "getBootServer"
}

function getMountPoint
{
	echo -n "What is the mount point of your bootserver?: "; read -r MOUNTPOINT
	if [ ! $MOUNTPOINT ]
		then 
			echo -e "\nNo value set.  Using defaults.\n"
			MOUNTPOINT=/nstation/linunx
	fi
}

function listMountPoints
{
	echo -e "\nAvailable mounts on: $BOOTSERVER\n\n"
	LINECOUNT=`showmount -e $BOOTSERVER | grep -vE "Export list" | wc -l`
	TEMP=`showmount -e $BOOTSERVER | grep -vE "Export list" | tr -s "*" " " | cut -f1 -d" " | tr -s "\n" "\t"`
	TEMPC=1	
	while [ $TEMPC -lt $LINECOUNT ]
	do
		MountArray[$TEMPC]=`echo $TEMP | cut -f$TEMPC -d" " | cut -f1 -d" "`
		echo -e "\t $TEMPC. ${MountArray[$TEMPC]}"
		TEMPC=$((TEMPC+1))
	done
	echo -e "\t 0. Quit"
	echo -e "\n"
	echo -n "Choose a mount point: "; read -r SELECT
	checkForRange $SELECT $((LINECOUNT-1)) "listMountPoints"
	MOUNTPOINT=${MountArray[$SELECT]}
}

function unmountBootServer
{
	echo -n "Unmounting Server..."
	umount /mnt/update
	echo -e " Done."
}

function mountBootServer
{
	echo -e "\n\n"
	echo  "Mounting $BOOTSERVER:$MOUNTPOINT  Please wait..."
	mkdir -p /mnt/update
        # Unmount any left over mounts, before mounting /mnt/update
        unmountBootServer

	mount $BOOTSERVER:$MOUNTPOINT /mnt/update
	if [ -d /mnt/update/IBM/update/idf ]
		then echo -e " Mount succesful."
	else
		echo -e " ERROR: Mount unsuccessful. Check $BOOTSERVER:$MOUNTPOINT/IBM/update/idf:"
		echo -e "        Directory not present or not accessible"
                unmountBootServer
		getBootServer
	fi
	echo -e "\n"
}

function listFlashImages
{
        # add check for existance of some idf files  ???


	echo -e "\nAvailable Flash Images on: $BOOTSERVER:$MOUNTPOINT\n\n"
	count=1
	for i in /mnt/update/IBM/update/idf/*.idf; do
		IDFArray[$count]=$i
		echo -e "\t $count. ${IDFArray[$count]}"
		count=$((count+1))
	done
	echo -e "\t 0. Quit"
	echo -e "\n"
	echo -n "Choose a Flash Image: "; read -r CHOICE
	checkForRange $CHOICE  $((count-1)) "listFlashImages"
	IMAGENAME=${IDFArray[$CHOICE]}
	export IMAGENAME
	
}

function checkForFlashReboot
{
        echo -e "\n"
	echo -n "On flash completion, do you want to reboot to Flash (y/n) ?: "; read -r input
        case $input in
		[yY]|[yY][eE][sS]) 
                   FLASH_REBOOT=y
                   ;;
		[nN]|[nN][oO])
                   FLASH_REBOOT=n
                   ;;
		*)
			echo -e "\nInvalid Response\n"
			checkForFlashReboot;;
	esac


}

function checkForDeltaUpdates
{
        echo -e "\n"
	echo -n "Is this a delta update of the flash [n] (y/n) ?: "; read -r input
        case $input in
		[yY]|[yY][eE][sS]) 
                   DELTA_UPDATE=y
                   PARTITION_FLASH=n
                   ;;
		*)
                   ;;
 	esac


}

function checkForPartitionFlash
{
        echo -e "\n"
	echo "Note: If the flash is not partitioned, it will have errors in subsequent steps"
	echo -n "Do you want to create the flash partition [ y ] : (y/n) ? "; read -r input

        case $input in
		[yY]|[yY][eE][sS]) 
                   PARTITION_FLASH=y
                   ;;
		[nN]|[nN][oO])
                   PARTITION_FLASH=n
                   ;;
		*)
			echo -e "\nInvalid Response\n"
			checkForPartitionFlash;;
	esac


}

function checkForRange # number upperlimit callingFunction
{
	BADCHOICE=0
	if [ $1 -eq 0 ]
		then
			umount /mnt/update
			sync;sync;sync
			exit
	fi

	if [ $1 -lt 1 ]
		then 
			BADCHOICE=1
	fi

	if [ $1 -gt $2 ]
		then
			BADCHOICE=1
	fi

	if [ $BADCHOICE -eq 1 ]
		then
			BADCHOICE=0
			echo -e "\nInvalid value.\n"
			$3
	fi
}

function callFlashInit
{
        if [ x$PARTITION_FLASH = x"y" ]; then
            echo -n "Partitioning Flash... Please Wait. "
           . /IBM/FlashRecovery/cf_flashinit.sh
        else
           echo -n "Mounting Flash... Please Wait. "
          . /IBM/FlashRecovery/cf_umount.sh
          . /IBM/FlashRecovery/cf_mount.sh
        fi
        echo " Done."
}

function updateFlash 
{
	echo -e "\n"
	file=`echo $1 | cut -c12- `
 echo file = $file
        if [ x$DELTA_UPDATE = x"y" ]; then
            echo "Updating Compact Flash Image with $1 "
            echo "... Please wait. "
            /IBM/bin/lcma  -s $file -m /mnt/update -r /mnt/hd1 -c $file > /IBM/FlashRecovery/update.log 2> /IBM/FlashRecovery/update.err
        else
            echo "Creating New Compact Flash Image with $1 "
            echo "... Please wait. "
            /IBM/bin/lcma -f -s $file -m /mnt/update -r /mnt/hd1 > /IBM/FlashRecovery/update.log 2> /IBM/FlashRecovery/update.err
        fi
}

function check_valid # number callingFunction 
{
	BADVAL=0
        TEMP=`echo $1 | tr -d "[a-z][A-Z][\-\"]"`
        if [ ${#TEMP} -ne ${#1} ]
                then BADVAL=1
        fi

        TEMP=`echo $1 | cut -f1 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f2 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f3 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f4 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi

	if [ $BADVAL -eq 1 ]
		then
			BADVAL=0
			echo -e "\nInvalid value\n";
			$2
	fi
} 

function check_for_automate
{
	if [ -f /IBM/FlashRecovery/autoupdate ]
		then
			. /IBM/FlashRecovery/autoupdate
			mountBootServer
	else
		getBootServer
		listMountPoints
		mountBootServer
		listFlashImages
                checkForDeltaUpdates
                checkForFlashReboot
             # Currently we always partition the flash - option needs to be enabled
             # when delta updates are enabled  
               #  checkForPartitionFlash
	fi
}			

function flashReboot
{
   echo "Set for Flash Reboot"

   # Uncomment next 2 lines for debug
   echo "For debug - type exit to continue "
   /bin/sh

   #  Check for error in building flash - if error, do not reboot ??? 

   # write to nvram - Boot file is /kernel.2#00 and localboot=Flash
   # tcPrimaryBootServerDirectory (id=22) is set to 4 - flashPrimaryBootDirDefault
   writeNvram   22   4
   # tcLocalPriority (id=33) is set to 1 - flash boot
   writeNvram   33   1

   # Reboot - forced w/o user confirmation
   if [ x$CONFIRM_REBOOT = x"y" ]; then
      echo -e "\n"
      echo -n "NVRAM changed to do flash reboot - Continue with reboot [n] : (y/n) ? "; read -r input
      if [ x$input = x"y" ]; then
         /IBM/bin/reboot_IBM_NS   5
      fi
   else   
      /IBM/bin/reboot_IBM_NS   5
   fi

}


#------------------------
# Start Main section 
#------------------------


#set-up defaults
PARTITION_FLASH=y
FLASH_REBOOT=n
CONFIRM_REBOOT=y
# used for delta update - if present, this will do delta updates rather than full idf updates
DELTA_UPDATE=n

# -- Start

/usr/bin/clear
echo -e "\nWelcome to IBM NetVista Flash Recovery Tool v1.0\n\n"

# Get inputs, if "autoupdate" file is not present
check_for_automate

# Partition/initialize Flash, if specified and mount /dev/hda1 and /dev/hda2
callFlashInit

#Update flash - calls lcma  
updateFlash $IMAGENAME

#Unmount server on /mnt/update
unmountBootServer

# Reboot from flash if so requested
if [ x$FLASH_REBOOT = x"y" ]; then
    flashReboot
fi

