#!/bin/sh
################################################################################
# Name: common_install.sh
# Purpose: Portiopns of the install process common to all distributions
# Last edited: 8/23/00
# Command:
#    common_install.sh
# Input (via environment variables), set by calling program:
#    CLIENT_VENDOR - vendor name (RedHat, Caldera, TurboLinux)
#    CLIENT_DISTRIBUTION  (example: 6.1, WorkStation6.0, etc)
#    RPM_LIST_FILE - file name for client rpm list to install
################################################################################

################################################################################
# preInstall_Verifications
################################################################################
function preInstall_Verifications
{
        # create a new tmp/bootDirValue file - holds boot, server, and other info 
        if [ -f tmp/bootDirValue ]; then
           rm -f tmp/bootDirValue
        fi
        touch tmp/bootDirValue

	# Determine if the current user is root - if not, exit
	curUser=`whoami`
	if [ $curUser != "root" ]; then
		echo -e "This install script must be run while logged in as root\n"
		exit 0
	fi

	# Be sure path contains local directory
	PATH=$PATH:.

	# If the current working directory is the same as the CDROM we should exit
	# as this can cause problems with mounting/unmounting the CDROMS
	if [ $CURDIR = $cdrom ]; then
		echo -e "\nDo not launch this installation from within the CDROM mount point.\n"
		exit 0
	fi

	# Prompt the end user for the server IP Address and verify it is a valid IP
	getServerIP

	# Prompt the end user for the server's Linux distribution
	serverDistribution

	# Prompt the end user for the installation directory
	echo -ne "\nInstallation Directory [ /nstation/linux ] : "; read BOOT_DIR
	if [ ! $BOOT_DIR ]; then
		BOOT_DIR=/nstation/linux
	fi
	echo "BOOT_DIR=$BOOT_DIR" >> tmp/bootDirValue
}

################################################################################
# continueQuestion
################################################################################
function continueQuestion
{
	echo -ne "\nDo you wish to continue? (Yes/No) "
	read input
	case $input in
		[yY]|[yY][eE][sS]) ;;
		[nN]|[nN][oO]) exit;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			continueQuestion;;
	esac
}

################################################################################
# setMachineBaseDir
################################################################################
function setMachineBaseDir
{
  echo ""
  echo "In normal installations, the client defines a RAMdisk to hold temporary data."
  echo -n "Should the boot server hold client specific data (e.g. /tmp) [ No ] ? (Yes/No) "
  read input
  case $input in
    [yY]|[yY][eE][sS])
      echo -n "Client Machine Specific directory [ $DEFAULT_MACHINE_BASE_DIR ] : "
      read MACHINE_BASE_DIR
      if [ ! $MACHINE_BASE_DIR ]; then
        MACHINE_BASE_DIR=$DEFAULT_MACHINE_BASE_DIR
      fi

      # Ask if temporary client data should be refreshed on every boot
      echo -n "Do you want client specific data persistent "
      echo -n "across client boot sessions [ No ] ? (Yes/No) "
      read persistent
      case $persistent in
        [yY]|[yY][eE][sS])
          MACHINE_DATA_PERSISTENT=y;;
        *)
          MACHINE_DATA_PERSISTENT=n;;
      esac
      ;;
    *)
      unset MACHINE_BASE_DIR;;
  esac
}

################################################################################
# getServerIP
################################################################################
function getServerIP
{
	while [ ! $validIP ]
	do
		echo -ne "\nServer IP Address: "; read IP
                if [ ! $IP ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
                fi
		TEMP=`echo $IP | tr -d "[a-z][A-Z][\-\"]"`
		if [ ${#TEMP} -ne ${#IP} ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
 
		TEMP=`echo $IP | cut -f1 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		TEMP=`echo $IP | cut -f2 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		TEMP=`echo $IP | cut -f3 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		TEMP=`echo $IP | cut -f4 -d"."`
		if [ $TEMP -gt 255 ]; then
			if [ ! $validIP ]; then
				echo -e "\nInvalid value"; getServerIP;
			fi
		fi
		validIP=1
	done
}

################################################################################
# serverDistribution
################################################################################
function serverDistribution
{
	CALDERA="Caldera Open Linux"
	REDHAT="RedHat Linux"
	SUSE="SuSe Linux"
	TURBO="TurboLinux"
	OTHER="Other"
	
	echo ""
	PS3="Which Linux distribution are you running on this server? "
	select i in "$CALDERA" "$REDHAT" "$SUSE" "$TURBO" "$OTHER"
	do
		case $i in
			"$CALDERA")
				DISTRIBUTION="$CALDERA"
				break;;
			"$REDHAT")
				DISTRIBUTION="$REDHAT"
				break ;;
			"$SUSE")
				DISTRIBUTION="$SUSE"
				break ;;
			"$TURBO")
				DISTRIBUTION="$TURBO"
				break ;;
			"$OTHER")
				DISTRIBUTION="$OTHER"
				break ;;
		esac
	done
	echo "SERVER=\"$DISTRIBUTION\"" >> tmp/bootDirValue

}

################################################################################
# Main Body
################################################################################
set +x

# ============ Start ======================
preInstall_Verifications

# ==========  Set Linux distribution specific Variables ===========================

# Default Settings
RC_BOOT_FILE=rc.sysinit
REBOOT_NEEDED=y

valid_client=n

# Specific setting for TurboLinux Client
if [ x$CLIENT_VENDOR = x"TurboLinux" ]; then
   valid_client=y
   REBOOT_NEEDED=y
   # Name of boot file to be modified
   RC_BOOT_FILE=rc.sysinit
   # RPM source directory (ends with slash)
   if [ ! $cdrom ]; then
      RPM_SOURCE_DIR=/mnt/cdrom/TurboLinux/RPMS/
   else
      RPM_SOURCE_DIR=$cdrom/TurboLinux/RPMS/
   fi
   RPM_ITERATIONS=2
fi
  
# Specific setting for RedHat Client
if [ x$CLIENT_VENDOR = x"RedHat" ]; then
   valid_client=y
   REBOOT_NEEDED=n
   # Name of boot file to be modified
   RC_BOOT_FILE=rc.sysinit
   # RPM source directory (ends with slash)
   if [ ! $cdrom ]; then
      RPM_SOURCE_DIR=/mnt/cdrom/RedHat/RPMS/
   else
      RPM_SOURCE_DIR=$cdrom/RedHat/RPMS/
   fi
   RPM_ITERATIONS=1
fi

# Specific setting for Caldera Client
if [ x$CLIENT_VENDOR = x"Caldera" ]; then
   valid_client=y
   echo "Support for Caldera not present"
   exit 1
fi

#check if its a valid client
if [ x$valid_client = x"n" ]; then 
   echo " "
   echo "ERROR: Invalid client vendor specified CLIENT_VENDOR = <$CLIENT_VENDOR>"
   echo "       Run the appropriate wrapper (e.g. tl_create_bootdir_from_rpm.sh)"
   echo "       Installation exiting"
   exit 1
fi

# Name of modified boot file
IBM_RC_BOOT_FILE=${RC_BOOT_FILE}.IBM_NS.sboot

# ==========  Set Common Variables applicable to client distributions ===========================

# Set the dir name of nc specific file - could be in tmp if tmp is a RAM disk, or could
# be in tmp.nc for nc specific files - Whatever is done here must match between 
# this script file and IBM_RC_BOOT_FILE (rc.sysinit.IBM_NS.sboot) file
# script
TMP_DIR=tmp

DEFAULT_MACHINE_BASE_DIR=/nstation/machines
MACHINE_TEMPLATE=NONKIOSK_SBOOT_TEMPLATE
MACHINE_DATA_PERSISTENT=n

#set MACHINE_BASE_DIR - directory that holds client-machine specific data (/tmp, var, etc)
MACHINE_BASE_DIR=$3
if [ ! "$MACHINE_BASE_DIR" ]; then
	setMachineBaseDir
fi

#current_dir=`pwd`

# Check if CDROM is mounted and files are present - CHECK if correct CD is present ???
if [ -d $RPM_SOURCE_DIR ]; then
  echo ""
else
  CDMOUNTED=`df | grep $cdrom | grep -v grep | wc -l`
  if [ $CDMOUNTED != 0 ]; then
    umount $cdrom
  fi
  CDMOUNTED=0
  while [ $CDMOUNTED = 0 ]
  do
    echo -e "\nPlease insert the $CLIENT_VENDOR $CLIENT_DISTRIBUTION CD"
    echo -n "   Press <ENTER> To Continue "; read
    echo ""
    CDMOUNTED=`df | grep $cdrom | grep -v grep | wc -l`
    if [ $CDMOUNTED = 0 ]; then
      mount $cdrom
      CDMOUNTED=`df | grep $cdrom | grep -v grep | wc -l`
    fi
    # Check if its the correct CD
    if [ ! -d $RPM_SOURCE_DIR ]; then
      umount $cdrom
      CDMOUNTED=0
    fi
  done
fi

if [ $BOOT_DIR = "/" ]; then
  echo -e "\nERROR: Attempting to install on the '/' directory - This will CORRUPT your server set-up"
  echo -e "         Installion terminating"
  exit
fi

echo "Installation of Server Boot $CLIENT_VENDOR $CLIENT_DISTRIBUTION Linux client for IBM NetVista thin client"
echo "Current selections: " 
echo "   Server IP address: " $IP
echo "   Client boot directory: " $BOOT_DIR
if [ x$MACHINE_BASE_DIR = x ]; then
  echo "   No Client SPECIFIC directory specified - Will use RAM disk for /tmp space"
else
  echo "   Client SPECIFIC directory: " $MACHINE_BASE_DIR
  echo "   Client data persistent across boot sessions: " $MACHINE_DATA_PERSISTENT
fi
# if [ -e $CFBUILDER ]; then
#   echo "   Compact Flash Builder tool source file: " $CFBUILDER
# fi

# Check for existing installation
CLIENT_UPGRADE=n
if [ -d $BOOT_DIR/var.nc_shared ]; then
  echo ""
  echo "WARNING: Client boot directory set-up exists - This will upgrade the installation"
  CLIENT_UPGRADE=y
fi
#if [ -d $BOOT_DIR ]; then
#  echo ""
#  echo "WARNING: Client boot directory already exists - this will overwrite the previous installation"
#fi

# Be sure the administrator wants to continue the installation with these settings
continueQuestion

#exit

# ============  Create infrastructure for RPM installation  =================
# create the boot dir - do we need to check is boot image has alredy been created
Common/scripts/mkdirhier ${BOOT_DIR}

# Create the directories, files needed for next step of RPM installation
if [ x$CLIENT_UPGRADE = x"y" ]; then 
  echo "Set-up for UPGRADE INSTALL "
  rm $BOOT_DIR/var
  mv $BOOT_DIR/var.nc_shared   $BOOT_DIR/var
else
  echo "Set-up for NEW INSTALL "
  cp -pR RPM_INSTALL_PREREQ/*   $BOOT_DIR
fi

# ==========  Perform distribution specific setup

if [ x$CLIENT_VENDOR = x"TurboLinux" ]; then
   #export the display - needed by some TurboLinux 6.0 Japan RPMs, like elisa*, kaname*, kanji18*, etc. 
   #   the default display of :0 does not work, so we set it to the server address
   # Check if this is needed for TL English version
   export DISPLAY=$IP:0.0
fi

# ============  Install RPMS from a shell script =================
if [ ! -f $RPM_LIST_FILE ]; then
   echo ERROR: No rpm list file $RPM_LIST_FILE present - Check the package
   exit
fi
awk -fCommon/scripts/create_rpm_script_awk -vRPM_OPTIONS="--excludedocs" -vROOT=$BOOT_DIR -vRPM_DIR=$RPM_SOURCE_DIR  ./$RPM_LIST_FILE > ./tmp/extract_rpm.sh
chmod a+x ./tmp/extract_rpm.sh

#exit

echo "INSTALL RPMS - ITERATION # 1 (THIS WILL TAKE APPROXIMATELY 10-15 MINUTES) ... "
echo "   - Ignore any warnings/errors during this iteration - they will be resolved in the next iteration "
tmp/extract_rpm.sh

if [ $RPM_ITERATIONS -gt 1 ]; then
   echo "INSTALL RPMS - ITERATION # 2 (THIS WILL TAKE APPROXIMATELY 10-15 MINUTES) ... "
   tmp/extract_rpm.sh
fi

# remove /boot directory
rm -rf $BOOT_DIR/boot

echo ""

# ============ Create  /etc/fstab file  ========================
echo "Create " $BOOT_DIR"/etc/fstab file"
if [ -f $BOOT_DIR/etc/fstab.org ]; then
  echo $BOOT_DIR/etc/fstab.org file already exists
else
  if [ -f $BOOT_DIR/etc/fstab ]; then
    mv $BOOT_DIR/etc/fstab $BOOT_DIR/etc/fstab.org
  fi
fi
echo "## Generated for IBM Network Station " > $BOOT_DIR/etc/fstab
echo $IP:$BOOT_DIR " /  nfs  defaults  1 1" >> $BOOT_DIR/etc/fstab
echo "none   /proc  proc     defaults  0 0" >> $BOOT_DIR/etc/fstab
echo "none   /dev/pts   devpts  gid=5,mode=620  0 0" >> $BOOT_DIR/etc/fstab

# ============ Modify /etc/inittab file  ========================
echo "Modify $BOOT_DIR/etc/inittab to call $IBM_RC_BOOT_FILE"
if [ -f $BOOT_DIR/etc/inittab.org ]; then
  echo $BOOT_DIR/etc/inittab.org file already exists
else
  mv $BOOT_DIR/etc/inittab $BOOT_DIR/etc/inittab.org
fi
awk -fCommon/scripts/inittab_awk -vREPLACE=$RC_BOOT_FILE -vBY=$IBM_RC_BOOT_FILE  $BOOT_DIR/etc/inittab.org > $BOOT_DIR/etc/inittab

# For GUI-login - currently commented out, until we have menu options for GUI-login
#cp $BOOT_DIR/etc/inittab  $BOOT_DIR/etc/inittab.tmp
#awk -fCommon/scripts/inittab_awk  -vREPLACE="id:3:initdefault:" -vBY="id:5:initdefault:"  $BOOT_DIR/etc/inittab.tmp > $BOOT_DIR/etc/inittab

# =====================================================================================
#   Rename unneeded services  
# =====================================================================================
echo "Rename services not needed for IBM NetVista Thin Clients"
#if [ -f $BOOT_DIR/etc/rc.d/init.d/network ]; then
#  mv  $BOOT_DIR/etc/rc.d/init.d/network  $BOOT_DIR/etc/rc.d/init.d/network.sav
#fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/atd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/atd      $BOOT_DIR/etc/rc.d/init.d/atd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/apmd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/apmd      $BOOT_DIR/etc/rc.d/init.d/apmd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/kudzu ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/kudzu    $BOOT_DIR/etc/rc.d/init.d/kudzu.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/crond ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/crond    $BOOT_DIR/etc/rc.d/init.d/crond.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/nfs ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/nfs    $BOOT_DIR/etc/rc.d/init.d/nfs.sav
fi
#if [ -f $BOOT_DIR/etc/rc.d/init.d/syslog ]; then
#  mv  $BOOT_DIR/etc/rc.d/init.d/syslog    $BOOT_DIR/etc/rc.d/init.d/syslog.sav
#fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/sendmail ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/sendmail    $BOOT_DIR/etc/rc.d/init.d/sendmail.sav
fi

if [ -f $BOOT_DIR/etc/rc.d/init.d/random ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/random $BOOT_DIR/etc/rc.d/init.d/random.sav
fi



# change 2 byte OEM identifier in ICA client
if [ -f $BOOT_DIR/usr/lib/ICAClient/wfica ]; then
	Common/scripts/setoemid $BOOT_DIR/usr/lib/ICAClient/wfica 808A
fi

# create wrapper for ica client
if [ -f $BOOT_DIR/usr/lib/ICAClient/wfcmgr ]; then
	if [ -f $BOOT_DIR/usr/bin/wfcmgr ]; then
		rm -f $BOOT_DIR/usr/bin/wfcmgr
	fi
	echo "#!/bin/sh" > $BOOT_DIR/usr/bin/wfcmgr
	echo "cd /usr/lib/ICAClient" >> $BOOT_DIR/usr/bin/wfcmgr
	echo "./wfcmgr" >> $BOOT_DIR/usr/bin/wfcmgr
	chmod 755 $BOOT_DIR/usr/bin/wfcmgr
fi


# =====================================================================================
#   Add new files
# =====================================================================================
echo "Add new Common Files "
cp -pR Common/COMMON_FILES/*  $BOOT_DIR
echo "Add $CLIENT_VENDOR $CLIENT_DISTRIBUTION Specific Files "
cp -pR SPECIFIC_FILES/*  $BOOT_DIR
# Force /tmp directory be RW - Some server setup (Caldera) has $BOOT_DIR/tmp set to RW for root only
chmod a+w $BOOT_DIR/$TMP_DIR


# =====================================================================================
#   Link files directories to TMP_RAM_DISK - these are uniques file for each client
# =====================================================================================
echo "Link files to RAM disk"
# ==== Create link for var directory (created in RAM disk in /$TMP_DIR)  =======
#Link var directory - var created in ram disk under /$TMP_DIR
if [ -d $BOOT_DIR/var.nc_shared ]; then
  echo "Original var backup already present"
else
  echo "Backup var directory"
  mv $BOOT_DIR/var $BOOT_DIR/var.nc_shared
fi
ln -sf /$TMP_DIR/var $BOOT_DIR/var

#==== Link files used for networking
ln -sf /$TMP_DIR/HOSTNAME     $BOOT_DIR/etc/HOSTNAME
ln -sf /$TMP_DIR/hosts        $BOOT_DIR/etc/hosts
ln -sf /$TMP_DIR/resolv.conf  $BOOT_DIR/etc/resolv.conf
ln -sf /$TMP_DIR/network      $BOOT_DIR/etc/sysconfig/network

#==== Link files used for keyboard
ln -sf /$TMP_DIR/keyboard     $BOOT_DIR/etc/sysconfig/keyboard

#==== Link /etc/mtab file 
if [ -f $BOOT_DIR/etc/mtab ]; then
  rm $BOOT_DIR/etc/mtab
fi
ln -sf /$TMP_DIR/mtab $BOOT_DIR/etc/mtab

#==== Link loadable lib modules file 
rm -rf $BOOT_DIR/lib/modules
ln -sf /$TMP_DIR/lib-modules $BOOT_DIR/lib/modules


# link rpm dir on / to the actual - this is done to make server install of RPMS easy by
#   using the following command:  rpm -i --root BOOT_DIR <rpm-file-name>
#   Without the link, use "rpm -i --dbpath BOOT_DIR/var.nc_shared/lib/rpm <rpm-file-name>
#ln -sf var.nc_shared/lib/rpm $BOOT_DIR/rpm

# =====================================================================================
#   Perform any client specific operation
# =====================================================================================
if [ x$CLIENT_VENDOR = x"TurboLinux" ]; then
   # for TurboLinux 6.0.5, /etc/services.rpmnew needs to be renames as /etc/servcies
   if [ -f $BOOT_DIR/etc/services.rpmnew ]; then
      mv $BOOT_DIR/etc/services.rpmnew  $BOOT_DIR/etc/services
   fi
fi

# =====================================================================================
#   Set-up Xserver files for FrameBuffer or SVGA 
#   Make sure to change rc.IBM_NS.tmp to make the correct /tmp/XF86Config link
# =====================================================================================
XSERVER=FBUF
if [ $XSERVER = "SVGA" ]; then
  echo "Setup Xserver files - XF86_SVGA and XF86Config"
  # following line is for Japanese version only
  #  cp  Common/XSERVER_CHANGES/XF86Config.SVGA.jp    $BOOT_DIR/etc/X11/XF86Config.SVGA
  cp  Common/XSERVER_CHANGES/XF86Config.SVGA    $BOOT_DIR/etc/X11/XF86Config.SVGA
  cp  Common/XSERVER_CHANGES/XF86_SVGA          $BOOT_DIR/usr/X11R6/bin/
  if [ -f $BOOT_DIR/etc/X11/XF86Config.org ]; then
    echo "XF86Config.org already exists - no need to backup original"
  else
    if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
      mv $BOOT_DIR/etc/X11/XF86Config  $BOOT_DIR/etc/X11/XF86Config.org
    fi
  fi
  if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
    rm $BOOT_DIR/etc/X11/XF86Config
  fi
  ln -sf XF86Config.SVGA   $BOOT_DIR/etc/X11/XF86Config
  if [ -f $BOOT_DIR/etc/X11/X ]; then
    mv $BOOT_DIR/etc/X11/X $BOOT_DIR/etc/X11/X.org
  fi
  ln -sf /usr/X11R6/bin/XF86_SVGA  $BOOT_DIR/etc/X11/X             

else             

  ## For Frame buffer  ###
  echo "Setup Xserver files - XF86_FBDev and XF86Config"
#  cp  Common/XSERVER_CHANGES/XF86Config.FBDev.2800    $BOOT_DIR/etc/X11/
#  cp  Common/XSERVER_CHANGES/XF86Config.FBDev.2200    $BOOT_DIR/etc/X11/
  cp  Common/XSERVER_CHANGES/XF86Config.FBDev    $BOOT_DIR/etc/X11/
  if [ -f $BOOT_DIR/etc/X11/XF86Config.org ]; then
     echo "XF86Config.org already exists - no need to backup original"
  else
    if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
      mv $BOOT_DIR/etc/X11/XF86Config  $BOOT_DIR/etc/X11/XF86Config.org
    fi
  fi
  if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
    rm $BOOT_DIR/etc/X11/XF86Config
  fi
  ln -sf /$TMP_DIR/XF86Config  $BOOT_DIR/etc/X11/XF86Config
#  ln -sf XF86Config.FBDev.2800 $BOOT_DIR/etc/X11/XF86Config.2800
#  ln -sf XF86Config.FBDev.2200 $BOOT_DIR/etc/X11/XF86Config.2200

  # Link appropriate Xserver files
  if [ -f $BOOT_DIR/etc/X11/X ]; then
    mv $BOOT_DIR/etc/X11/X   $BOOT_DIR/etc/X11/X.org
  fi
  ln -sf /usr/X11R6/bin/XF86_FBDev  $BOOT_DIR/etc/X11/X             
  ln -sf /usr/X11R6/bin/XF86_FBDev  $BOOT_DIR/usr/X11R6/bin/X             

fi

# =====================================================================================
# Remove the unnecessary /dev entries from the BOOT_DIR tree
# =====================================================================================
#cp $BOOT_DIR/dev/MAKEDEV /tmp/
rm -rf $BOOT_DIR/dev/*
#mv /tmp/MAKEDEV $BOOT_DIR/dev/

# =====================================================================================
# Create machine specific dir ($MACHINE_BASE_DIR)
#  Template for this set-up is located in BOOT_DIR/IBM?TEMPLATES dir.
# =====================================================================================
if [ "$MACHINE_BASE_DIR" ]; then
   Common/scripts/mkdirhier  ${MACHINE_BASE_DIR}   
   echo "Machine specific template base directory" > ${MACHINE_BASE_DIR}/TEMPLATE_README
fi

# create /etc/rc.d/machineDir.IBM_NS.setup file contain MACHINE dir setup
# if $MACHINE_BASE_DIR is undefined, the file will have NULL value for MACHINE_BASE_DIR
echo MACHINE_BASE_DIR=$MACHINE_BASE_DIR > $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup
echo MACHINE_TEMPLATE=$MACHINE_TEMPLATE >> $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup
echo MACHINE_DATA_PERSISTENT=$MACHINE_DATA_PERSISTENT >> $BOOT_DIR/etc/rc.d/machineDir.IBM_NS.setup

# =====================================================================================
# Generate /IBM/linuxDistribution (for version control) and /etc.motd files 
# =====================================================================================
. version
echo -e "$CLIENT_VENDOR $CLIENT_DISTRIBUTION - IBM Version $linux_dist_ver ($linux_dist_date)\n" > $BOOT_DIR/IBM/linuxDistribution
echo -e "Welcome to $CLIENT_VENDOR $CLIENT_DISTRIBUTION - IBM Version $linux_dist_ver ($linux_dist_date)\n" > $BOOT_DIR/etc/motd
# Build $BOOT_DIR/IBM/version file
echo "linux_vendor=$CLIENT_VENDOR" > $BOOT_DIR/IBM/version
echo "linux_dist=$CLIENT_DISTRIBUTION" >> $BOOT_DIR/IBM/version
cat version Common/version >> $BOOT_DIR/IBM/version


# =====================================================================================
# Export $BOOT_DIR
# =====================================================================================
temp=`grep $BOOT_DIR /etc/exports`
echo ""

if [ ! "$temp" ]; then
	echo "ETC_EXPORTS_MOD=y" >> tmp/bootDirValue
	if [ "$DISTRIBUTION" = "$REDHAT" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$CALDERA" ]; then
		echo -n "Domain name for the clients which will be be booting from this server: "; read
		echo "$BOOT_DIR		*.$REPLY(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$TURBO" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "The TurboLinux NFSd package relies upon the /etc/hosts.allow & /etc/hosts.deny"
		echo "files - if you have troubles booting your client, please consult the"
		echo "man pages for exports, hosts.allow, hosts.deny"
	elif [ "$DISTRIBUTION" = "$SUSE" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$OTHER" ]; then
		echo "$BOOT_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "Your NFS server may require some configuration changes."
		echo "Consult the man pages for exports, hosts.allow, hosts.deny"
	fi

	echo "Added $BOOT_DIR to /etc/exports"
else
	echo "No change required for NFS export configuration"
fi

if [ "$MACHINE_BASE_DIR" ]; then
  temp=`grep $MACHINE_BASE_DIR /etc/exports`
  if [ ! "$temp" ]; then
	echo "ETC_EXPORTS_MOD=y" >> tmp/bootDirValue
	if [ "$DISTRIBUTION" = "$REDHAT" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$CALDERA" ]; then
		echo -n "Domain name for the clients which will be be booting from this server: "; read
		echo "$MACHINE_BASE_DIR		*.$REPLY(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$TURBO" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "The TurboLinux NFSd package relies upon the /etc/hosts.allow & /etc/hosts.deny"
		echo "files - if you have troubles booting your client, please consult the"
		echo "man pages for exports, hosts.allow, hosts.deny"
	elif [ "$DISTRIBUTION" = "$SUSE" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
	elif [ "$DISTRIBUTION" = "$OTHER" ]; then
		echo "$MACHINE_BASE_DIR		*(rw,no_root_squash)" >> /etc/exports
		echo "Your NFS server may require some configuration changes."
		echo "Consult the man pages for exports, hosts.allow, hosts.deny"
	fi

	echo "Added $MACHINE_BASE_DIR to /etc/exports"
  fi
fi

# =====================================================================================
# Copy the html documentation to the client tree for easy access
# =====================================================================================
cp -pR ../html $BOOT_DIR/IBM/

# =====================================================================================
# Extract the Flash Management Tutorial DOCS
# =====================================================================================
if [ -e /tmp/flash_manage_tutorial.tar.gz ]; then
	echo "Installing the Flash Management Tutorial documents in /IBM"
	tar -C $BOOT_DIR/IBM/ -xzf /tmp/flash_manage_tutorial.tar.gz
	rm -rf /tmp/flash_manage_tutorial.tar.gz
fi

# =====================================================================================
# chmod /usr/bin/smbmount for SMB home directory support
# =====================================================================================
if [ -f $BOOT_DIR/usr/sbin/smbmount ]; then
  chmod u+s $BOOT_DIR/usr/sbin/smbmount
fi

# ==========  Install the Linux Client Management Utility  ====================
if [ -e $CFBUILDER ]; then
	echo -e "\nInstalling CFBuilder"
	tar -C $BOOT_DIR/IBM/ -xzf $CFBUILDER
fi


echo " "
echo "Client Directory Setup complete"
