#!/bin/sh
################################################################################
# Name: rh_install.sh
#
# Purpose: Create a RedHat 6.1 tree for serving IBM NetVista
#          thin clients
# Last edited: 8/23/00
# Command:
#  rh_install.sh
################################################################################

################################################################################
# reboot_Warning
################################################################################
function reboot_Warning
{
	echo "If installing on a server other than RedHat Linux server, upon completion of"
	echo "this install, the system must be rebooted (see install html for more info):"
        echo ""
	echo -n "Do you wish to continue? (Yes/No) "; read
	case $REPLY in
		[yY]|[yY][eE][sS])
			;;
		[nN]|[nN][oO])
			echo ""
			exit 0;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			reboot_Warning;;
	esac
}

################################################################################
# what_client_to_install
################################################################################
function what_client_to_install
{
	echo "Please select the client you wish to install:"
	echo "  1. RedHat 6.1 "
	echo "  2. RedHat 6.2 "
        echo -n "Enter Selection: "; read
	case $REPLY in
		[1])
                    . CONFIG/rh61.config;;
		[2])
                    . CONFIG/rh62.config;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			what_client_to_install;;
	esac
}


################################################################################
# Main Body
################################################################################

set +x

# =======  Set Linux distribution specific Variables - used by calling script files ========

# --- Default settings - the ACTUAL settings come from the selection by the user

#default client info
export CLIENT_VENDOR=RedHat
export CLIENT_DISTRIBUTION=6.1

#  default RPM list file for the Linux distrubution
export RPM_LIST_FILE=RPM_LISTS/rh61_rpm.list

# default CFBuilder
export CFBUILDER="Common/CFBuilder/CFBuilder_2.5_RedHat61_*"


# ============ Start ======================
# Let's clear the screen to make things cleaner looking
clear
echo -e "\nWelcome to the IBM NetVista Thin Client RedHat Linux Installer\n"

export CURDIR=`pwd`

TEMP_SCRIPT_LOC=`ps axo command | grep -v grep | grep rh_install | cut -f2 -d" " | tr -s "\n" "\t" | cut -f1`
SCRIPT_LOC=${TEMP_SCRIPT_LOC%/*}
cd $SCRIPT_LOC

#echo TEMP_SCRIPT_LOC = $TEMP_SCRIPT_LOC
#echo SCRIPT_LOC = $SCRIPT_LOC

# ========== Ask if rebooting is ok =================
reboot_Warning

# ========== Tell the administrator where the installation log can be found ===========
echo -e "\nAfter the installation has finished, the installation log (install.log) will be"
echo "located in $SCRIPT_LOC/tmp directory"
echo -e " - Please review this file if problems are encountered.\n"

# ========== Ask what client to install =================
# Once the RedHat 6.2  rpm list is finalised, use the function, until then use rh61.config file
#what_client_to_install
. CONFIG/rh61.config

# From the Function what_client_to_install
echo " "
export CLIENT_DISTRIBUTION
export RPM_LIST_FILE
export CLIENT_VENDOR
export CFBUILDER

# ========== Get the CDROM mount point location ====================
echo -n "CDROM Drive Mount Point [ /mnt/cdrom ] ? "; read cdrom
if [ ! $cdrom ]; then 
        cdrom="/mnt/cdrom"
fi
export cdrom
echo ""

# ==========  Execute common script file for all client distributions  ====================
Common/scripts/common_install.sh 2>&1 | tee tmp/install.log

# ==========  Be sure the administrator did not exit early ===================
# Need to do a two fold check because of points at which the administrator
# can abort the installation
if [ -f tmp/bootDirValue ]; then
        . tmp/bootDirValue
        if [ ! -e $BOOT_DIR/IBM/linuxDistribution ]; then
                echo -e "\nInstallation aborted\n"
                exit 0
        fi
else
        echo -e "\nInstallation aborted\n"
        exit 0
fi

# ==========   DONE - Time to reboot if using a server other than RedHat   ====================
#  Reboot is done to solve the /proc problem 
# -------------------------------------------------------
umount $cdrom
echo -e "\nInstallation is Complete - Remove the $CLIENT_VENDOR $CLIENT_DISTRIBUTION CD\n"
. tmp/bootDirValue
#echo "SERVER=$SERVER" 
REDHAT="RedHat Linux"
if [ "$SERVER" = "$REDHAT" ]; then
   if [ "$ETC_EXPORTS_MOD" ]; then
      echo "Server exports file (/etc/exports) was modified. NFS needs to be restarted"
      echo -n "Would you like to restart NFS services [ No ] ? (y/n): "
      read input
      if [ x$input = x"y" -o x$input = x"Y" ]; then
          /etc/rc.d/init.d/nfs stop
          /etc/rc.d/init.d/nfs start
      else
          echo -n "Please manually restart NFS before booting NetVista thin client"
      fi
   fi
else
   echo -n "   Press <ENTER> to Reboot the System "; read
   echo ""
   reboot
fi
echo ""
echo "INSTALLATION IS COMPLETE !!! "
echo ""