#!/bin/sh
################################################################################
# Name: tl_install.sh
# Purpose: Create a TurboLinux tree for serving IBM NetVista thin clients
# Last edited: 8/23/00
# Command:
#  tl_install.sh
################################################################################

################################################################################
# reboot_Warning
################################################################################
function reboot_Warning
{
	echo "Upon completion of this install, the system must be rebooted."
	echo -n "Do you wish to continue? (Yes/No) "; read
	case $REPLY in
		[yY]|[yY][eE][sS])
			;;
		[nN]|[nN][oO])
			echo ""
			exit 0;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			reboot_Warning;;
	esac
}


################################################################################
# what_client_to_install
################################################################################
function what_client_to_install
{
	echo "Please select the client you wish to install:"
	echo "  1. TurboLinux WorkStation 6.0.7 (Official IBM distribution) "
	echo "  2. TurboLinux WorkStation 6.0.5 "
	echo "  3. TurboLinux WorkStation 6.0 "
        echo -n "Enter Selection: "; read
	case $REPLY in
		[1])
                    . CONFIG/tlw607.config;;
		[2])
                    . CONFIG/tlw605.config;;
		[3])
                    . CONFIG/tlw60.config;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			what_client_to_install;;
	esac
}

################################################################################
# Main Body
################################################################################
README="/tmp/README.html"

set +x

# =======  Set Linux distribution specific Variables - used by calling script files ========


# default client info
export CLIENT_VENDOR=TurboLinux
export CLIENT_DISTRIBUTION="WorkStation 6.0.7"

# default RPM list file for the Linux distrubution
export RPM_LIST_FILE=RPM_LISTS/tlw607_rpm.list

# default CFBuilder
export CFBUILDER="Common/CFBUILDER/CFBuilder_2.5_TurboLinux607_*"


# ============ Start ======================
# Let's clear the screen to make things cleaner looking
clear
echo -e "\nWelcome to the IBM NetVista Thin Client TurboLinux Installer\n"

export CURDIR=`pwd`

TEMP_SCRIPT_LOC=`ps axo command | grep -v grep | grep tl_install | cut -f2 -d" " | tr -s "\n" "\t" | cut -f1`
SCRIPT_LOC=${TEMP_SCRIPT_LOC%/*}
cd $SCRIPT_LOC

#echo TEMP_SCRIPT_LOC = $TEMP_SCRIPT_LOC
#echo SCRIPT_LOC = $SCRIPT_LOC

# ========== Ask if rebooting is ok =================
reboot_Warning


# ========== Tell the administrator where the installation log can be found ===========
echo -e "\nAfter the installation has finished, the installation log (install.log) will be"
echo "located in $SCRIPT_LOC/tmp directory"
echo -e " - Please review this file if problems are encountered.\n" 

# ========== Ask what client to install =================
if [ ! -f /tmp/nvltc_type ]; then
   # Invoked from toolkit - give user a choice
   what_client_to_install
else  
   # Invoked from official build CD - this is a fixed distribution - No choice given
   . CONFIG/tlw607.config
fi
# From the Function what_client_to_install
echo " "
export CLIENT_DISTRIBUTION
export RPM_LIST_FILE
export CLIENT_VENDOR
export CFBUILDER

# ========== Get the CDROM mount point location ====================
echo -n "CDROM Drive Mount Point [ /mnt/cdrom ] ? "; read cdrom
if [ ! $cdrom ]; then
	cdrom="/mnt/cdrom"
fi
echo ""
export cdrom

# ==========  Execute common script file for all client distributions  ====================
Common/scripts/common_install.sh 2>&1 | tee tmp/install.log

# ==========  Be sure the administrator did not exit early ===================
# Need to do a two fold check because of points at which the administrator
# can abort the installation
if [ -f tmp/bootDirValue ]; then
	. tmp/bootDirValue
	if [ ! -e $BOOT_DIR/IBM/linuxDistribution ]; then
		echo -e "\nInstallation aborted\n"
		exit 0
	fi
else
	echo -e "\nInstallation aborted\n"
	exit 0
fi

# ==========  Install the Linux Client Management Utility  ====================
#if [ -e $CFBUILDER ]; then
#	echo -e "\nInstalling CFBuilder"
#	tar -C $BOOT_DIR/IBM/ -xzf $CFBUILDER
#	rm $CFBUILDER
#fi

# ==========  Copy the CD README.html file to the /IBM directory  ====================
if [ -e $README ]; then
	cp $README $BOOT_DIR/IBM/
	rm $README
fi

# ==========  Remove some doc directories since we didn't install docs  ====================
rm -rf $BOOT_DIR/usr/share/doc
rm -rf $BOOT_DIR/usr/X11R6/doc
rm -rf $BOOT_DIR/usr/X11R6/man/ja_JP.ujis
rm -rf $BOOT_DIR/usr/doc
rm -rf $BOOT_DIR/usr/local/doc

# ==========   DONE - Time to reboot  ====================
umount $cdrom
echo -e "\nInstallation is Complete - Remove the $CLIENT_VENDOR $CLIENT_DISTRIBUTION CD\n"
echo -n "   Press <ENTER> to Reboot the System "; read
echo ""
reboot
